@@ -38,12 +38,23 @@
 #ifndef __PyCXX_wrap_python_hxx__
 #define __PyCXX_wrap_python_hxx__
 
-/* Python API mandates Python.h is included *first* */
-#include "Python.h"
-
 // On some platforms we have to include time.h to get select defined
 #if !defined(__WIN32__) && !defined(WIN32) && !defined(_WIN32) && !defined(_WIN64)
 #include <sys/time.h>
 #endif
 
+// Prevent multiple conflicting definitions of swab from stdlib.h and unistd.h
+#if defined(__sun) || defined(sun)
+#if defined(_XPG4)
+#undef _XPG4
+#endif
+#endif
+
+// Python.h will redefine these and generate warning in the process
+#undef _XOPEN_SOURCE
+#undef _POSIX_C_SOURCE
+
+// pull in python definitions
+#include <Python.h>
+
 #endif
