@@ -4,7 +4,7 @@ import matplotlib.pyplot as plt
 fig = plt.figure()
 ax = fig.gca(projection='3d')
 X, Y, Z = axes3d.get_test_data(0.05)
-cset = ax.contour(X, Y, Z, 16, extend3d=True)
+cset = ax.contour(X, Y, Z, extend3d=True)
 ax.clabel(cset, fontsize=9, inline=1)
 
 plt.show()
