@@ -31,8 +31,8 @@ def generate_example_rst(app):
     datad = {}
     for root, subFolders, files in os.walk(rootdir):
         for fname in files:
-            if ( fname.startswith('.') or fname.startswith('#') or fname.startswith('_') or
-                 fname.find('.svn')>=0 or not fname.endswith('.py') ):
+            if ( fname.startswith('.') or fname.startswith('#')
+                 or fname.startswith('_') or not fname.endswith('.py') ):
                 continue
 
             fullpath = os.path.join(root,fname)
@@ -111,7 +111,7 @@ Matplotlib Examples
             rstfile = '%s.rst'%basename
             outrstfile = os.path.join(rstdir, rstfile)
 
-            fhsubdirIndex.write('    %s\n'%rstfile)
+            fhsubdirIndex.write('    %s <%s>\n'%(os.path.basename(basename),rstfile))
 
             if not out_of_date(fullpath, outrstfile):
                 continue
