@@ -1,8 +1,10 @@
 import numpy as np
 import matplotlib.mlab as mlab
+import matplotlib.cbook as cbook
 
-
-r = mlab.csv2rec('../data/aapl.csv')
+datafile = cbook.get_sample_data('aapl.csv', asfileobj=False)
+print 'loading', datafile
+r = mlab.csv2rec(datafile)
 r.sort()
 
 def daily_return(prices):
