@@ -108,7 +108,7 @@ latex_to_bakoma = {
     r'7'                         : ('cmr10',  127),
     r'8'                         : ('cmr10',   77),
     r'9'                         : ('cmr10',   22),
-    r'                           :'                    : ('cmr10',   85),
+    r':'                         : ('cmr10',   85),
     r';'                         : ('cmr10',   31),
     r'='                         : ('cmr10',   41),
     r'\leftbracket'              : ('cmr10',   62),
@@ -160,8 +160,6 @@ latex_to_bakoma = {
     r'\nwarrow'                  : ('cmsy10',  65),
     r'\swarrow'                  : ('cmsy10', 116),
     r'\propto'                   : ('cmsy10',  15),
-    r'\prime'                    : ('cmsy10',  73),
-    r"'"                         : ('cmsy10',  73),
     r'\infty'                    : ('cmsy10',  32),
     r'\in'                       : ('cmsy10',  59),
     r'\ni'                       : ('cmsy10', 122),
@@ -245,6 +243,9 @@ latex_to_bakoma = {
     r'\rightarrow'               : ('cmsy10',  12),
     r'\to'                       : ('cmsy10',  12),
     r'\spadesuit'                : ('cmsy10',   7),
+    r'?'                         : ('cmr10',   50),
+    r'!'                         : ('cmr10',   29),
+    r'&'                         : ('cmr10',  109) 
 }
 
 latex_to_cmex = {
@@ -2321,7 +2322,21 @@ tex2uni = {
     'biguplus'                 : 10756,
     'epsilon'                  : 949,
     'vartheta'                 : 977,
-    'bigotimes'                : 10754
+    'bigotimes'                : 10754,
+    'guillemotleft'            : 171,
+    'ring'                     : 730,
+    'Thorn'                    : 222,
+    'guilsinglright'           : 8250,
+    'perthousand'              : 8240,
+    'macron'                   : 175,
+    'cent'                     : 162,
+    'guillemotright'           : 187,
+    'equal'                    : 61,
+    'asterisk'                 : 42,
+    'guilsinglleft'            : 8249,
+    'plus'                     : 43,
+    'thorn'                    : 254,
+    'dagger'                   : 8224
 }
 
 # Each element is a 4-tuple of the form:
@@ -2355,17 +2370,17 @@ stix_virtual_fonts = {
             [
             (0x0030, 0x0039, 'rm', 0x1d7d8), # 0-9
             (0x0041, 0x0042, 'it', 0xe154),  # A-B
-            (0x0043, 0x0043, 'it', 0x2102),  # C (missing in beta STIX fonts)
+            (0x0043, 0x0043, 'it', 0x2102),  # C
             (0x0044, 0x0044, 'it', 0x2145),  # D
             (0x0045, 0x0047, 'it', 0xe156),  # E-G
-            (0x0048, 0x0048, 'it', 0x210d),  # H (missing in beta STIX fonts)
+            (0x0048, 0x0048, 'it', 0x210d),  # H
             (0x0049, 0x004d, 'it', 0xe159),  # I-M
-            (0x004e, 0x004e, 'it', 0x2115),  # N (missing in beta STIX fonts)
+            (0x004e, 0x004e, 'it', 0x2115),  # N
             (0x004f, 0x004f, 'it', 0xe15e),  # O
-            (0x0050, 0x0051, 'it', 0x2119),  # P-Q (missing in beta STIX fonts)
-            (0x0052, 0x0052, 'it', 0x211d),  # R (missing in beta STIX fonts)
+            (0x0050, 0x0051, 'it', 0x2119),  # P-Q
+            (0x0052, 0x0052, 'it', 0x211d),  # R
             (0x0053, 0x0059, 'it', 0xe15f),  # S-Y
-            (0x005a, 0x005a, 'it', 0x2124),  # Z (missing in beta STIX fonts)
+            (0x005a, 0x005a, 'it', 0x2124),  # Z
             (0x0061, 0x0063, 'it', 0xe166),  # a-c
             (0x0064, 0x0065, 'it', 0x2146),  # d-e
             (0x0066, 0x0068, 'it', 0xe169),  # f-h
@@ -2380,8 +2395,23 @@ stix_virtual_fonts = {
         'bf':
             [
             (0x0030, 0x0039, 'rm', 0x1d7d8), # 0-9
-            (0x0041, 0x005a, 'bf', 0xe38a),  # A-Z
-            (0x0061, 0x007a, 'bf', 0xe39d),  # a-z
+            (0x0041, 0x0042, 'bf', 0xe38a),  # A-B
+            (0x0043, 0x0043, 'bf', 0x2102),  # C
+            (0x0044, 0x0044, 'bf', 0x2145),  # D
+            (0x0045, 0x0047, 'bf', 0xe38d),  # E-G
+            (0x0048, 0x0048, 'bf', 0x210d),  # H
+            (0x0049, 0x004d, 'bf', 0xe390),  # I-M
+            (0x004e, 0x004e, 'bf', 0x2115),  # N
+            (0x004f, 0x004f, 'bf', 0xe395),  # O
+            (0x0050, 0x0051, 'bf', 0x2119),  # P-Q
+            (0x0052, 0x0052, 'bf', 0x211d),  # R
+            (0x0053, 0x0059, 'bf', 0xe396),  # S-Y
+            (0x005a, 0x005a, 'bf', 0x2124),  # Z
+            (0x0061, 0x0063, 'bf', 0xe39d),  # a-c
+            (0x0064, 0x0065, 'bf', 0x2146),  # d-e
+            (0x0066, 0x0068, 'bf', 0xe3a2),  # f-h
+            (0x0069, 0x006a, 'bf', 0x2148),  # i-j
+            (0x006b, 0x007a, 'bf', 0xe3a7),  # k-z
             (0x0393, 0x0393, 'bf', 0x213e),  # \Gamma
             (0x03a0, 0x03a0, 'bf', 0x213f),  # \Pi
             (0x03a3, 0x03a3, 'bf', 0x2140),  # \Sigma
@@ -2462,7 +2492,7 @@ stix_virtual_fonts = {
         (0x0049, 0x0049, 'it', 0x2110),  # I
         (0x004a, 0x004b, 'it', 0x1d4a5), # J-K
         (0x004c, 0x004c, 'it', 0x2112),  # L
-        (0x004d, 0x003d, 'it', 0x2113),  # M
+        (0x004d, 0x003d, 'it', 0x2133),  # M
         (0x004e, 0x0051, 'it', 0x1d4a9), # N-Q
         (0x0052, 0x0052, 'it', 0x211b),  # R
         (0x0053, 0x005a, 'it', 0x1d4ae), # S-Z
