@@ -167,7 +167,7 @@ class Tick(artist.Artist):
     set_clip_path.__doc__ = artist.Artist.set_clip_path.__doc__
 
     def get_pad_pixels(self):
-        return self.figure.dpi * self._pad / 72.0
+        return self.figure.dpi * self._base_pad / 72.0
 
     def contains(self, mouseevent):
         """
@@ -185,11 +185,11 @@ class Tick(artist.Artist):
 
         ACCEPTS: float
         """
-        self._pad = val
+        self._apply_params(pad=val)
 
     def get_pad(self):
         'Get the value of the tick label pad in points'
-        return self._pad
+        return self._base_pad
 
     def _get_text1(self):
         'Get the default Text 1 instance'
@@ -262,9 +262,6 @@ class Tick(artist.Artist):
         'return the view Interval instance for the axis this tick is ticking'
         raise NotImplementedError('Derived must override')
 
-    def set_view_interval(self, vmin, vmax, ignore=False):
-        raise NotImplementedError('Derived must override')
-
     def _apply_params(self, **kw):
         switchkw = ['gridOn', 'tick1On', 'tick2On', 'label1On', 'label2On']
         switches = [k for k in kw if k in switchkw]
@@ -445,20 +442,6 @@ class XTick(Tick):
         'return the Interval instance for this axis view limits'
         return self.axes.viewLim.intervalx
 
-    def set_view_interval(self, vmin, vmax, ignore = False):
-        if ignore:
-            self.axes.viewLim.intervalx = vmin, vmax
-        else:
-            Vmin, Vmax = self.get_view_interval()
-            self.axes.viewLim.intervalx = min(vmin, Vmin), max(vmax, Vmax)
-
-    def get_minpos(self):
-        return self.axes.dataLim.minposx
-
-    def get_data_interval(self):
-        'return the Interval instance for this axis data limits'
-        return self.axes.dataLim.intervalx
-
 
 class YTick(Tick):
     """
@@ -595,20 +578,6 @@ class YTick(Tick):
         'return the Interval instance for this axis view limits'
         return self.axes.viewLim.intervaly
 
-    def set_view_interval(self, vmin, vmax, ignore = False):
-        if ignore:
-            self.axes.viewLim.intervaly = vmin, vmax
-        else:
-            Vmin, Vmax = self.get_view_interval()
-            self.axes.viewLim.intervaly = min(vmin, Vmin), max(vmax, Vmax)
-
-    def get_minpos(self):
-        return self.axes.dataLim.minposy
-
-    def get_data_interval(self):
-        'return the Interval instance for this axis data limits'
-        return self.axes.dataLim.intervaly
-
 
 class Ticker:
     locator = None
@@ -650,7 +619,7 @@ class Axis(artist.Artist):
         self.axes = axes
         self.major = Ticker()
         self.minor = Ticker()
-        self.callbacks = cbook.CallbackRegistry(('units', 'units finalize'))
+        self.callbacks = cbook.CallbackRegistry()
 
         #class dummy:
         #    locator = None
@@ -745,7 +714,7 @@ class Axis(artist.Artist):
         self.isDefault_label = True
 
         # Clear the callback registry for this axis, or it may "leak"
-        self.callbacks = cbook.CallbackRegistry(('units', 'units finalize'))
+        self.callbacks = cbook.CallbackRegistry()
 
         # whether the grids are on
         self._gridOnMajor = rcParams['axes.grid']
@@ -924,22 +893,9 @@ class Axis(artist.Artist):
         Get the extents of the tick labels on either side
         of the axes.
         """
-        ticklabelBoxes = []
-        ticklabelBoxes2 = []
 
-        interval = self.get_view_interval()
-        for tick, loc, label in self.iter_ticks():
-            if tick is None: continue
-            if not mtransforms.interval_contains(interval, loc): continue
-            tick.update_position(loc)
-            tick.set_label1(label)
-            tick.set_label2(label)
-            if tick.label1On and tick.label1.get_visible():
-                extent = tick.label1.get_window_extent(renderer)
-                ticklabelBoxes.append(extent)
-            if tick.label2On and tick.label2.get_visible():
-                extent = tick.label2.get_window_extent(renderer)
-                ticklabelBoxes2.append(extent)
+        ticks_to_draw = self._update_ticks(renderer)
+        ticklabelBoxes, ticklabelBoxes2 = self._get_tick_bboxes(ticks_to_draw, renderer)
 
         if len(ticklabelBoxes):
             bbox = mtransforms.Bbox.union(ticklabelBoxes)
@@ -959,14 +915,13 @@ class Axis(artist.Artist):
         """get whether the axis has smart bounds"""
         return self._smart_bounds
 
-    @allow_rasterization
-    def draw(self, renderer, *args, **kwargs):
-        'Draw the axis lines, grid lines, tick lines and labels'
-        ticklabelBoxes = []
-        ticklabelBoxes2 = []
+    def _update_ticks(self, renderer):
+        """
+        Update ticks (position and labels) using the current data
+        interval of the axes. Returns a list of ticks that will be
+        drawn.
+        """
 
-        if not self.get_visible(): return
-        renderer.open_group(__name__)
         interval = self.get_view_interval()
         tick_tups = [ t for t in self.iter_ticks()]
         if self._smart_bounds:
@@ -1008,19 +963,81 @@ class Axis(artist.Artist):
                 tick_tups = [ ti for ti in tick_tups
                               if (ti[1] >= ilow) and (ti[1] <= ihigh)]
 
+        ticks_to_draw = []
         for tick, loc, label in tick_tups:
             if tick is None: continue
             if not mtransforms.interval_contains(interval, loc): continue
             tick.update_position(loc)
             tick.set_label1(label)
             tick.set_label2(label)
-            tick.draw(renderer)
+            ticks_to_draw.append(tick)
+
+        return ticks_to_draw
+
+    def _get_tick_bboxes(self, ticks, renderer):
+        """
+        Given the list of ticks, return two lists of bboxes. One for
+        tick lable1's and another for tick label2's.
+        """
+
+        ticklabelBoxes = []
+        ticklabelBoxes2 = []
+
+        for tick in ticks:
             if tick.label1On and tick.label1.get_visible():
                 extent = tick.label1.get_window_extent(renderer)
                 ticklabelBoxes.append(extent)
             if tick.label2On and tick.label2.get_visible():
                 extent = tick.label2.get_window_extent(renderer)
                 ticklabelBoxes2.append(extent)
+        return ticklabelBoxes, ticklabelBoxes2
+
+    def get_tightbbox(self, renderer):
+        """
+        Return a bounding box that encloses the axis. It only accounts
+        tick labels, axis label, and offsetText.
+        """
+        if not self.get_visible(): return
+
+        ticks_to_draw = self._update_ticks(renderer)
+        ticklabelBoxes, ticklabelBoxes2 = self._get_tick_bboxes(ticks_to_draw, renderer)
+
+        self._update_label_position(ticklabelBoxes, ticklabelBoxes2)
+
+        self._update_offset_text_position(ticklabelBoxes, ticklabelBoxes2)
+        self.offsetText.set_text( self.major.formatter.get_offset() )
+
+
+        bb = []
+
+        for a in [self.label, self.offsetText]:
+            if a.get_visible():
+                bb.append(a.get_window_extent(renderer))
+
+        bb.extend(ticklabelBoxes)
+        bb.extend(ticklabelBoxes2)
+
+        #self.offsetText
+        bb = [b for b in bb if b.width!=0 or b.height!=0]
+        if bb:
+            _bbox = mtransforms.Bbox.union(bb)
+            return _bbox
+        else:
+            return None
+
+
+    @allow_rasterization
+    def draw(self, renderer, *args, **kwargs):
+        'Draw the axis lines, grid lines, tick lines and labels'
+
+        if not self.get_visible(): return
+        renderer.open_group(__name__)
+
+        ticks_to_draw = self._update_ticks(renderer)
+        ticklabelBoxes, ticklabelBoxes2 = self._get_tick_bboxes(ticks_to_draw, renderer)
+
+        for tick in ticks_to_draw:
+            tick.draw(renderer)
 
         # scale up the axis label box to also find the neighbors, not
         # just the tick labels that actually overlap note we need a
@@ -1249,21 +1266,21 @@ class Axis(artist.Artist):
     def update_units(self, data):
         """
         introspect *data* for units converter and update the
-        axis.converter instance if necessary. Return *True* is *data* is
-        registered for unit conversion
+        axis.converter instance if necessary. Return *True*
+        if *data* is registered for unit conversion.
         """
 
         converter = munits.registry.get_converter(data)
-        if converter is None: return False
+        if converter is None:
+            return False
 
         neednew = self.converter!=converter
         self.converter = converter
         default = self.converter.default_units(data, self)
-        #print 'update units: default="%s", units=%s"'%(default, self.units)
+        #print 'update units: default=%s, units=%s'%(default, self.units)
         if default is not None and self.units is None:
             self.set_units(default)
 
-
         if neednew:
             self._update_axisinfo()
         return True
@@ -1484,14 +1501,21 @@ class Axis(artist.Artist):
         self.major.locator.zoom(direction)
 
 
-    def axis_date(self):
+    def axis_date(self, tz=None):
         """
         Sets up x-axis ticks and labels that treat the x data as dates.
+        *tz* is a :class:`tzinfo` instance or a timezone string.
+        This timezone is used to create date labels.
         """
+        # By providing a sample datetime instance with the desired
+        # timezone, the registered converter can be selected,
+        # and the "units" attribute, which is the timezone, can
+        # be set.
         import datetime
-        # should be enough to inform the unit conversion interface
-        # dates are comng in
-        self.update_units(datetime.date(2009,1,1))
+        if isinstance(tz, (str, unicode)):
+            import pytz
+            tz = pytz.timezone(tz)
+        self.update_units(datetime.datetime(2009,1,1,0,0,0,0,tz))
 
 
 class XAxis(Axis):
@@ -1528,7 +1552,8 @@ class XAxis(Axis):
         # time by _update_label_positions)
         label = mtext.Text(x=0.5, y=0,
             fontproperties = font_manager.FontProperties(
-                                          size=rcParams['axes.labelsize']),
+                               size=rcParams['axes.labelsize'],
+                               weight=rcParams['axes.labelweight']),
             color = rcParams['axes.labelcolor'],
             verticalalignment='top',
             horizontalalignment='center',
@@ -1699,7 +1724,11 @@ class XAxis(Axis):
         """
         If *ignore* is *False*, the order of vmin, vmax
         does not matter; the original axis orientation will
-        be preserved.
+        be preserved. In addition, the view limits can be
+        expanded, but will not be reduced.  This method is
+        for mpl internal use; for normal use, see
+        :meth:`~matplotlib.axes.Axes.set_xlim`.
+
         """
         if ignore:
             self.axes.viewLim.intervalx = vmin, vmax
@@ -1785,7 +1814,8 @@ class YAxis(Axis):
         label = mtext.Text(x=0, y=0.5,
             # todo: get the label position
             fontproperties=font_manager.FontProperties(
-                                        size=rcParams['axes.labelsize']),
+                               size=rcParams['axes.labelsize'],
+                               weight=rcParams['axes.labelweight']),
             color    = rcParams['axes.labelcolor'],
             verticalalignment='center',
             horizontalalignment='right',
@@ -1960,7 +1990,11 @@ class YAxis(Axis):
         """
         If *ignore* is *False*, the order of vmin, vmax
         does not matter; the original axis orientation will
-        be preserved.
+        be preserved. In addition, the view limits can be
+        expanded, but will not be reduced.  This method is
+        for mpl internal use; for normal use, see
+        :meth:`~matplotlib.axes.Axes.set_ylim`.
+
         """
         if ignore:
             self.axes.viewLim.intervaly = vmin, vmax
