@@ -21,7 +21,7 @@ Naming Conventions
 from __future__ import division
 import os, sys, warnings, gzip
 
-import numpy as npy
+import numpy as np
 
 def _fn_name(): return sys._getframe(1).f_code.co_name
 
@@ -96,6 +96,8 @@ class RendererCairo(RendererBase):
            cairo.ImageSurface (cairo.FORMAT_ARGB32,1,1))
         self.mathtext_parser = MathTextParser('Cairo')
 
+        RendererBase.__init__(self)
+
     def set_ctx_from_surface (self, surface):
         self.gc.ctx = cairo.Context (surface)
 
@@ -139,7 +141,7 @@ class RendererCairo(RendererBase):
 
     def draw_path(self, gc, path, transform, rgbFace=None):
         if len(path.vertices) > 18980:
-           raise ValueError("The Cairo backend can not draw paths longer than 18980 points.")
+            raise ValueError("The Cairo backend can not draw paths longer than 18980 points.")
 
         ctx = gc.ctx
 
@@ -151,10 +153,12 @@ class RendererCairo(RendererBase):
 
         self._fill_and_stroke(ctx, rgbFace, gc.get_alpha())
 
-    def draw_image(self, x, y, im, bbox, clippath=None, clippath_trans=None):
+    def draw_image(self, gc, x, y, im):
         # bbox - not currently used
         if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
 
+        clippath, clippath_trans = gc.get_clip_path()
+
         im.flipud_out()
 
         rows, cols, buf = im.color_conv (BYTE_FORMAT)
@@ -194,7 +198,7 @@ class RendererCairo(RendererBase):
 
            ctx.save()
            if angle:
-              ctx.rotate (-angle * npy.pi / 180)
+              ctx.rotate (-angle * np.pi / 180)
            ctx.set_font_size (size)
            ctx.show_text (s.encode("utf-8"))
            ctx.restore()
@@ -209,7 +213,7 @@ class RendererCairo(RendererBase):
         ctx.save()
         ctx.translate(x, y)
         if angle:
-           ctx.rotate (-angle * npy.pi / 180)
+           ctx.rotate (-angle * np.pi / 180)
 
         for font, fontsize, s, ox, oy in glyphs:
            ctx.new_path()
@@ -279,6 +283,8 @@ class RendererCairo(RendererBase):
     def new_gc(self):
         if _debug: print '%s.%s()' % (self.__class__.__name__, _fn_name())
         self.gc.ctx.save()
+        self.gc._alpha = 1.0
+        self.gc._forced_alpha = False # if True, _alpha overrides A from RGBA
         return self.gc
 
 
@@ -311,9 +317,10 @@ class GraphicsContextCairo(GraphicsContextBase):
 
 
     def set_alpha(self, alpha):
-        self._alpha = alpha
+        GraphicsContextBase.set_alpha(self, alpha)
+        _alpha = self.get_alpha()
         rgb = self._rgb
-        self.ctx.set_source_rgba (rgb[0], rgb[1], rgb[2], alpha)
+        self.ctx.set_source_rgba (rgb[0], rgb[1], rgb[2], _alpha)
 
 
     #def set_antialiased(self, b):
@@ -353,7 +360,7 @@ class GraphicsContextCairo(GraphicsContextBase):
             self.ctx.set_dash([], 0)  # switch dashes off
         else:
             self.ctx.set_dash (
-               self.renderer.points_to_pixels (npy.asarray(dashes)), offset)
+               self.renderer.points_to_pixels (np.asarray(dashes)), offset)
 
 
     def set_foreground(self, fg, isRGB=None):
@@ -467,7 +474,7 @@ class FigureCanvasCairo (FigureCanvasBase):
         ctx = renderer.gc.ctx
 
         if orientation == 'landscape':
-            ctx.rotate (npy.pi/2)
+            ctx.rotate (np.pi/2)
             ctx.translate (0, -height_in_points)
             # cairo/src/cairo_ps_surface.c
             # '%%Orientation: Portrait' is always written to the file header
