@@ -51,6 +51,55 @@ backend_version = 'Level II'
 
 debugPS = 0
 
+class PsBackendHelper(object):
+
+    def __init__(self):
+        self._cached = {}
+
+    @property
+    def gs_exe(self):
+        """
+        excutable name of ghostscript.
+        """
+        try:
+            return self._cached["gs_exe"]
+        except KeyError:
+            pass
+
+        if sys.platform == 'win32': gs_exe = 'gswin32c'
+        else: gs_exe = 'gs'
+
+        self._cached["gs_exe"] = gs_exe
+        return gs_exe
+
+    
+    @property
+    def gs_version(self):
+        """
+        version of ghostscript.
+        """
+        try:
+            return self._cached["gs_version"]
+        except KeyError:
+            pass
+
+        from subprocess import Popen, PIPE
+        pipe = Popen(self.gs_exe + " --version",
+                     shell=True, stdout=PIPE).stdout
+        gs_version = tuple(map(int, pipe.read().strip().split(".")))
+
+        self._cached["gs_version"] = gs_version
+        return gs_version
+
+    @property
+    def supports_ps2write(self):
+        """
+        True if the installed ghostscript supports ps2write device.
+        """
+        return self.gs_version[0] >= 9
+    
+ps_backend_helper = PsBackendHelper()
+
 papersize = {'letter': (8.5,11),
              'legal': (8.5,14),
              'ledger': (11,17),
@@ -1363,16 +1412,24 @@ def gs_distill(tmpfile, eps=False, ptype='letter', bbox=None, rotated=False):
     operators. The output is low-level, converting text to outlines.
     """
 
-    paper_option = "-sPAPERSIZE=%s" % ptype
+    if eps: paper_option = "-dEPSCrop"
+    else: paper_option = "-sPAPERSIZE=%s" % ptype
 
     psfile = tmpfile + '.ps'
     outfile = tmpfile + '.output'
     dpi = rcParams['ps.distiller.res']
-    if sys.platform == 'win32': gs_exe = 'gswin32c'
-    else: gs_exe = 'gs'
 
-    command = '%s -dBATCH -dNOPAUSE -r%d -sDEVICE=pswrite %s -sOutputFile="%s" \
-                "%s" > "%s"'% (gs_exe, dpi, paper_option, psfile, tmpfile, outfile)
+
+    gs_exe = ps_backend_helper.gs_exe
+    if ps_backend_helper.supports_ps2write: # gs version >= 9
+        device_name = "ps2write"
+    else:
+        device_name = "pswrite"
+
+    command = '%s -dBATCH -dNOPAUSE -r%d -sDEVICE=%s %s -sOutputFile="%s" \
+                "%s" > "%s"'% (gs_exe, dpi, device_name,
+                               paper_option, psfile, tmpfile, outfile)
+
     verbose.report(command, 'debug')
     exit_status = os.system(command)
     fh = file(outfile)
@@ -1386,11 +1443,18 @@ your image.\nHere is the full report generated by ghostscript:\n\n' + fh.read())
 
 
     # While it is best if above steps preserve the original bounding
-    # box, it does not seems to be the case. pstoeps not only convert
-    # the input to eps format, but also restores the original bbox.
+    # box, there seem to be cases when it is not. For those cases,
+    # the original bbox can be restored during the pstoeps step.
 
     if eps:
-        pstoeps(tmpfile, bbox, rotated=rotated)
+        # For some versions of gs, above steps result in an ps file
+        # where the original bbox is no more correct. Do not adjust
+        # bbox for now.
+        if ps_backend_helper.supports_ps2write:
+            # fo gs version >= 9 w/ ps2write device
+            pstoeps(tmpfile, bbox, rotated=rotated)
+        else:
+            pstoeps(tmpfile)
 
 
 def xpdf_distill(tmpfile, eps=False, ptype='letter', bbox=None, rotated=False):
@@ -1432,17 +1496,12 @@ image.\nHere is the full report generated by pdftops: \n\n' + fh.read())
     os.remove(tmpfile)
     shutil.move(psfile, tmpfile)
 
-
-    # Similar to the gs_distillier case, ps2pdf does not seem to
-    # preserve the bbox of the original file (at least w/ gs
-    # 8.61). Thus, the original bbox need to be resotred.
-
     if eps:
-        pstoeps(tmpfile, bbox, rotated)
+        pstoeps(tmpfile)
+
     for fname in glob.glob(tmpfile+'.*'):
         os.remove(fname)
 
-
 def get_bbox_header(lbrt, rotated=False):
     """
     return a postscript header stringfor the given bbox lbrt=(l, b, r, t).
@@ -1505,13 +1564,18 @@ Here is the Ghostscript output:\n\n%s'% bbox_info)
     return '\n'.join([bbox_info, hires_bbox_info])
 
 
-def pstoeps(tmpfile, bbox, rotated=False):
+def pstoeps(tmpfile, bbox=None, rotated=False):
     """
-    Convert the postscript to encapsulated postscript.
+    Convert the postscript to encapsulated postscript.  The bbox of
+    the eps file will be replaced with the given *bbox* argument. If
+    None, original bbox will be used.
     """
 
     # if rotated==True, the output eps file need to be rotated
-    bbox_info, rotate = get_bbox_header(bbox, rotated=rotated)
+    if bbox:
+        bbox_info, rotate = get_bbox_header(bbox, rotated=rotated)
+    else:
+        bbox_info, rotate = None, None
 
     epsfile = tmpfile + '.eps'
     epsh = file(epsfile, 'w')
@@ -1522,7 +1586,8 @@ def pstoeps(tmpfile, bbox, rotated=False):
     while line:
         if line.startswith('%!PS'):
             print >>epsh, "%!PS-Adobe-3.0 EPSF-3.0"
-            print >>epsh, bbox_info
+            if bbox:
+                print >>epsh, bbox_info
         elif line.startswith('%%EndComments'):
             epsh.write(line)
             print >>epsh, '%%BeginProlog'
@@ -1537,10 +1602,10 @@ def pstoeps(tmpfile, bbox, rotated=False):
             if rotate:
                 print >>epsh, rotate
             break
-        elif line.startswith('%%Bound') \
-            or line.startswith('%%HiResBound') \
-            or line.startswith('%%DocumentMedia') \
-            or line.startswith('%%Pages'):
+        elif bbox and (line.startswith('%%Bound') \
+                       or line.startswith('%%HiResBound') \
+                       or line.startswith('%%DocumentMedia') \
+                       or line.startswith('%%Pages')):
             pass
         else:
             epsh.write(line)
@@ -1559,6 +1624,8 @@ def pstoeps(tmpfile, bbox, rotated=False):
             if rcParams['ps.usedistiller'] == 'xpdf':
                 # remove extraneous "end" operator:
                 line = tmph.readline()
+        elif line.startswith('%%PageBoundingBox'):
+            pass
         else:
             epsh.write(line)
         line = tmph.readline()
