@@ -6,7 +6,6 @@ from __future__ import division
 import os, sys
 import matplotlib
 from matplotlib import verbose
-from matplotlib.cbook import enumerate
 from matplotlib.figure import Figure
 
 from backend_agg import FigureCanvasAgg
@@ -115,10 +114,11 @@ class FigureCanvasQTAgg( FigureCanvasAgg, FigureCanvasQT ):
         # we are blitting here
         else:
             bbox = self.replot
-            w, h = int(bbox.width()), int(bbox.height())
-            l, t = bbox.ll().x().get(), bbox.ur().y().get()
+            l, b, r, t = bbox.extents
+            w = int(r) - int(l)
+            h = int(t) - int(b)
             reg = self.copy_from_bbox(bbox)
-            stringBuffer = reg.to_string()
+            stringBuffer = reg.to_string_argb()
             qImage = qt.QImage(stringBuffer, w, h, 32, None, 0, qt.QImage.IgnoreEndian)
             self.pixmap.convertFromImage(qImage, qt.QPixmap.Color)
             p.drawPixmap(qt.QPoint(l, self.renderer.height-t), self.pixmap)
@@ -135,7 +135,7 @@ class FigureCanvasQTAgg( FigureCanvasAgg, FigureCanvasQT ):
         if DEBUG: print "FigureCanvasQtAgg.draw", self
         self.replot = True
         FigureCanvasAgg.draw(self)
-        self.repaint( False )
+        self.repaint(False)
 
     def blit(self, bbox=None):
         """
