@@ -3,7 +3,7 @@
 formlayout
 ==========
 
-Module creating PyQt4 form dialogs/layouts to edit various type of parameters
+Module creating Qt form dialogs/layouts to edit various type of parameters
 
 
 formlayout License Agreement (MIT License)
@@ -34,10 +34,11 @@ OTHER DEALINGS IN THE SOFTWARE.
 """
 
 # History:
+# 1.0.10: added float validator (disable "Ok" and "Apply" button when not valid)
 # 1.0.7: added support for "Apply" button
 # 1.0.6: code cleaning
 
-__version__ = '1.0.7'
+__version__ = '1.0.10'
 __license__ = __doc__
 
 DEBUG = False
@@ -45,45 +46,50 @@ DEBUG = False
 import sys
 STDERR = sys.stderr
 
-try:
-    from PyQt4.QtGui import QFormLayout
-except ImportError:
-    raise ImportError, "Warning: formlayout requires PyQt4 >v4.3"
+from matplotlib.backends.qt4_compat import QtGui,QtCore
+if not hasattr(QtGui,'QFormLayout'):
+    raise ImportError, "Warning: formlayout requires PyQt4 >v4.3 or PySide"
 
-from PyQt4.QtGui import (QWidget, QLineEdit, QComboBox, QLabel, QSpinBox, QIcon,
-                         QStyle, QDialogButtonBox, QHBoxLayout, QVBoxLayout,
-                         QDialog, QColor, QPushButton, QCheckBox, QColorDialog,
-                         QPixmap, QTabWidget, QApplication, QStackedWidget,
-                         QDateEdit, QDateTimeEdit, QFont, QFontComboBox,
-                         QFontDatabase, QGridLayout)
-from PyQt4.QtCore import (Qt, SIGNAL, SLOT, QSize, QString,
-                          pyqtSignature, pyqtProperty)
-from datetime import date
+(QWidget, QLineEdit, QComboBox, QLabel, QSpinBox, QIcon,QStyle,
+ QDialogButtonBox, QHBoxLayout, QVBoxLayout, QDialog, QColor, QPushButton,
+ QCheckBox, QColorDialog, QPixmap, QTabWidget, QApplication, QStackedWidget,
+ QDateEdit, QDateTimeEdit, QFont, QFontComboBox, QFontDatabase, QGridLayout,
+ QFormLayout, QDoubleValidator) =\
+ (QtGui.QWidget, QtGui.QLineEdit, QtGui.QComboBox, QtGui.QLabel,
+ QtGui.QSpinBox, QtGui.QIcon, QtGui.QStyle, QtGui.QDialogButtonBox,
+ QtGui.QHBoxLayout, QtGui.QVBoxLayout, QtGui.QDialog, QtGui.QColor,
+ QtGui.QPushButton, QtGui.QCheckBox, QtGui.QColorDialog, QtGui.QPixmap,
+ QtGui.QTabWidget, QtGui.QApplication, QtGui.QStackedWidget, QtGui.QDateEdit,
+ QtGui.QDateTimeEdit, QtGui.QFont, QtGui.QFontComboBox, QtGui.QFontDatabase,
+ QtGui.QGridLayout, QtGui.QFormLayout, QtGui.QDoubleValidator)
 
+(Qt, SIGNAL, SLOT, QObject, QSize,pyqtSignature, pyqtProperty) =\
+(QtCore.Qt, QtCore.SIGNAL, QtCore.SLOT, QtCore.QObject, QtCore.QSize,
+ QtCore.Slot, QtCore.Property)
+
+import datetime
 
 class ColorButton(QPushButton):
     """
     Color choosing push button
     """
     __pyqtSignals__ = ("colorChanged(QColor)",)
-    
+
     def __init__(self, parent=None):
         QPushButton.__init__(self, parent)
         self.setFixedSize(20, 20)
         self.setIconSize(QSize(12, 12))
         self.connect(self, SIGNAL("clicked()"), self.choose_color)
         self._color = QColor()
-    
+
     def choose_color(self):
-        rgba, valid = QColorDialog.getRgba(self._color.rgba(),
-                                           self.parentWidget())
-        if valid:
-            color = QColor.fromRgba(rgba)
+        color = QColorDialog.getColor(self._color,self.parentWidget(),'')
+        if color.isValid():
             self.set_color(color)
-    
+
     def get_color(self):
         return self._color
-    
+
     @pyqtSignature("QColor")
     def set_color(self, color):
         if color != self._color:
@@ -92,7 +98,7 @@ class ColorButton(QPushButton):
             pixmap = QPixmap(self.iconSize())
             pixmap.fill(color)
             self.setIcon(QIcon(pixmap))
-    
+
     color = pyqtProperty("QColor", get_color, set_color)
 
 
@@ -102,7 +108,8 @@ def text_to_qcolor(text):
     Avoid warning from Qt when an invalid QColor is instantiated
     """
     color = QColor()
-    if isinstance(text, QString):
+    if isinstance(text, QObject):
+        # actually a QString, which is not provided by the new PyQt4 API:
         text = str(text)
     if not isinstance(text, (unicode, str)):
         return color
@@ -139,11 +146,11 @@ class ColorLayout(QHBoxLayout):
 
     def update_text(self, color):
         self.lineedit.setText(color.name())
-        
+
     def text(self):
         return self.lineedit.text()
-    
-    
+
+
 def font_is_installed(font):
     """Check if font is installed"""
     return [fam for fam in QFontDatabase().families() if unicode(fam)==font]
@@ -171,19 +178,18 @@ def qfont_to_tuple(font):
     return (unicode(font.family()), int(font.pointSize()),
             font.italic(), font.bold())
 
-
 class FontLayout(QGridLayout):
     """Font selection"""
     def __init__(self, value, parent=None):
         QGridLayout.__init__(self)
         font = tuple_to_qfont(value)
         assert font is not None
-        
+
         # Font family
         self.family = QFontComboBox(parent)
         self.family.setCurrentFont(font)
         self.addWidget(self.family, 0, 0, 1, -1)
-        
+
         # Font size
         self.size = QComboBox(parent)
         self.size.setEditable(True)
@@ -195,17 +201,17 @@ class FontLayout(QGridLayout):
         self.size.addItems([str(s) for s in sizelist])
         self.size.setCurrentIndex(sizelist.index(size))
         self.addWidget(self.size, 1, 0)
-        
+
         # Italic or not
         self.italic = QCheckBox(self.tr("Italic"), parent)
         self.italic.setChecked(font.italic())
         self.addWidget(self.italic, 1, 1)
-        
+
         # Bold or not
         self.bold = QCheckBox(self.tr("Bold"), parent)
         self.bold.setChecked(font.bold())
         self.addWidget(self.bold, 1, 2)
-        
+
     def get_font(self):
         font = self.family.currentFont()
         font.setItalic(self.italic.isChecked())
@@ -214,9 +220,15 @@ class FontLayout(QGridLayout):
         return qfont_to_tuple(font)
 
 
+def is_edit_valid(edit):
+    text = edit.text()
+    state = edit.validator().validate(text, 0)[0]
+
+    return state == QDoubleValidator.Acceptable
+
 class FormWidget(QWidget):
     def __init__(self, data, comment="", parent=None):
-        super(FormWidget, self).__init__(parent)
+        QWidget.__init__(self, parent)
         from copy import deepcopy
         self.data = deepcopy(data)
         self.widgets = []
@@ -230,7 +242,13 @@ class FormWidget(QWidget):
             print "*"*80
             print "COMMENT:", comment
             print "*"*80
-        self.setup()
+
+    def get_dialog(self):
+        """Return FormDialog instance"""
+        dialog = self.parent()
+        while not isinstance(dialog, QDialog):
+            dialog = dialog.parent()
+        return dialog
 
     def setup(self):
         for label, value in self.data:
@@ -272,29 +290,32 @@ class FormWidget(QWidget):
                 field.setCurrentIndex(selindex)
             elif isinstance(value, bool):
                 field = QCheckBox(self)
-                if value:
+                if value :
                     field.setCheckState(Qt.Checked)
-                else:
-                    field.setCheckedState(Qt.Unchecked)
-                               
+                else :
+                    field.setCheckState(Qt.Unchecked)
             elif isinstance(value, float):
                 field = QLineEdit(repr(value), self)
+                field.setValidator(QDoubleValidator(field))
+                dialog = self.get_dialog()
+                dialog.register_float_field(field)
+                self.connect(field, SIGNAL('textChanged(QString)'),
+                             lambda text: dialog.update_buttons())
             elif isinstance(value, int):
                 field = QSpinBox(self)
+                field.setRange(-1e9, 1e9)
                 field.setValue(value)
-                field.setMaximum(1e9)
-            elif isinstance(value, date):
-                if hasattr(value, 'hour'):
-                    field = QDateTimeEdit(self)
-                    field.setDateTime(value)
-                else:
-                    field = QDateEdit(self)
-                    field.setDate(value)
+            elif isinstance(value, datetime.datetime):
+                field = QDateTimeEdit(self)
+                field.setDateTime(value)
+            elif isinstance(value, datetime.date):
+                field = QDateEdit(self)
+                field.setDate(value)
             else:
                 field = QLineEdit(repr(value), self)
             self.formlayout.addRow(label, field)
             self.widgets.append(field)
-            
+
     def get(self):
         valuelist = []
         for index, (label, value) in enumerate(self.data):
@@ -318,11 +339,10 @@ class FormWidget(QWidget):
                 value = float(field.text())
             elif isinstance(value, int):
                 value = int(field.value())
-            elif isinstance(value, date):
-                if hasattr(value, 'hour'):
-                    value = field.dateTime().toPyDateTime()
-                else:
-                    value = field.date().toPyDate()
+            elif isinstance(value, datetime.datetime):
+                value = field.dateTime().toPyDateTime()
+            elif isinstance(value, datetime.date):
+                value = field.date().toPyDate()
             else:
                 value = eval(str(field.text()))
             valuelist.append(value)
@@ -331,17 +351,17 @@ class FormWidget(QWidget):
 
 class FormComboWidget(QWidget):
     def __init__(self, datalist, comment="", parent=None):
-        super(FormComboWidget, self).__init__(parent)
+        QWidget.__init__(self, parent)
         layout = QVBoxLayout()
         self.setLayout(layout)
         self.combobox = QComboBox()
         layout.addWidget(self.combobox)
-        
+
         self.stackwidget = QStackedWidget(self)
         layout.addWidget(self.stackwidget)
         self.connect(self.combobox, SIGNAL("currentIndexChanged(int)"),
                      self.stackwidget, SLOT("setCurrentIndex(int)"))
-        
+
         self.widgetlist = []
         for data, title, comment in datalist:
             self.combobox.addItem(title)
@@ -349,13 +369,17 @@ class FormComboWidget(QWidget):
             self.stackwidget.addWidget(widget)
             self.widgetlist.append(widget)
 
+    def setup(self):
+        for widget in self.widgetlist:
+            widget.setup()
+
     def get(self):
         return [ widget.get() for widget in self.widgetlist]
-        
+
 
 class FormTabWidget(QWidget):
     def __init__(self, datalist, comment="", parent=None):
-        super(FormTabWidget, self).__init__(parent)
+        QWidget.__init__(self, parent)
         layout = QVBoxLayout()
         self.tabwidget = QTabWidget()
         layout.addWidget(self.tabwidget)
@@ -369,7 +393,11 @@ class FormTabWidget(QWidget):
             index = self.tabwidget.addTab(widget, title)
             self.tabwidget.setTabToolTip(index, comment)
             self.widgetlist.append(widget)
-            
+
+    def setup(self):
+        for widget in self.widgetlist:
+            widget.setup()
+
     def get(self):
         return [ widget.get() for widget in self.widgetlist]
 
@@ -378,10 +406,10 @@ class FormDialog(QDialog):
     """Form Dialog"""
     def __init__(self, data, title="", comment="",
                  icon=None, parent=None, apply=None):
-        super(FormDialog, self).__init__(parent)
+        QDialog.__init__(self, parent)
 
         self.apply_callback = apply
-        
+
         # Form
         if isinstance(data[0][0], (list, tuple)):
             self.formwidget = FormTabWidget(data, comment=comment,
@@ -390,13 +418,19 @@ class FormDialog(QDialog):
             self.formwidget = FormComboWidget(data, comment=comment,
                                               parent=self)
         else:
-            self.formwidget = FormWidget(data, comment=comment, 
+            self.formwidget = FormWidget(data, comment=comment,
                                          parent=self)
         layout = QVBoxLayout()
         layout.addWidget(self.formwidget)
-        
+
+        self.float_fields = []
+        self.formwidget.setup()
+
         # Button box
-        bbox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
+        self.bbox = bbox = QDialogButtonBox(QDialogButtonBox.Ok
+                                            |QDialogButtonBox.Cancel)
+        self.connect(self.formwidget, SIGNAL('update_buttons()'),
+                     self.update_buttons)
         if self.apply_callback is not None:
             apply_btn = bbox.addButton(QDialogButtonBox.Apply)
             self.connect(apply_btn, SIGNAL("clicked()"), self.apply)
@@ -405,23 +439,36 @@ class FormDialog(QDialog):
         layout.addWidget(bbox)
 
         self.setLayout(layout)
-        
+
         self.setWindowTitle(title)
         if not isinstance(icon, QIcon):
             icon = QWidget().style().standardIcon(QStyle.SP_MessageBoxQuestion)
         self.setWindowIcon(icon)
-        
+
+    def register_float_field(self, field):
+        self.float_fields.append(field)
+
+    def update_buttons(self):
+        valid = True
+        for field in self.float_fields:
+            if not is_edit_valid(field):
+                valid = False
+        for btn_type in (QDialogButtonBox.Ok, QDialogButtonBox.Apply):
+            btn = self.bbox.button(btn_type)
+            if btn is not None:
+                btn.setEnabled(valid)
+
     def accept(self):
         self.data = self.formwidget.get()
         QDialog.accept(self)
-        
+
     def reject(self):
         self.data = None
         QDialog.reject(self)
-        
+
     def apply(self):
         self.apply_callback(self.formwidget.get())
-        
+
     def get(self):
         """Return form result"""
         return self.data
@@ -431,22 +478,22 @@ def fedit(data, title="", comment="", icon=None, parent=None, apply=None):
     """
     Create form dialog and return result
     (if Cancel button is pressed, return None)
-    
+
     data: datalist, datagroup
     title: string
     comment: string
     icon: QIcon instance
     parent: parent QWidget
     apply: apply callback (function)
-    
+
     datalist: list/tuple of (field_name, field_value)
     datagroup: list/tuple of (datalist *or* datagroup, title, comment)
-    
+
     -> one field for each member of a datalist
     -> one tab for each member of a top-level datagroup
     -> one page (of a multipage widget, each page can be selected with a combo
        box) for each member of a datagroup inside a datagroup
-       
+
     Supported types for field_value:
       - int, float, str, unicode, bool
       - colors: in Qt-compatible text form, i.e. in hex format or name (red,...)
@@ -455,12 +502,12 @@ def fedit(data, title="", comment="", icon=None, parent=None, apply=None):
           * the first element will be the selected index (or value)
           * the other elements can be couples (key, value) or only values
     """
-    
+
     # Create a QApplication instance if no instance currently exists
     # (e.g. if the module is used directly from the interpreter)
     if QApplication.startingUp():
-        QApplication([])
-        
+        _app = QApplication([])
+
     dialog = FormDialog(data, title, comment, icon, parent, apply)
     if dialog.exec_():
         return dialog.get()
@@ -481,15 +528,16 @@ if __name__ == "__main__":
                 ('font', ('Arial', 10, False, True)),
                 ('color', '#123409'),
                 ('bool', True),
-                ('datetime', date(2010, 10, 10)),
+                ('date', datetime.date(2010, 10, 10)),
+                ('datetime', datetime.datetime(2010, 10, 10)),
                 ]
-        
+
     def create_datagroup_example():
         datalist = create_datalist_example()
         return ((datalist, "Category 1", "Category 1 comment"),
                 (datalist, "Category 2", "Category 2 comment"),
                 (datalist, "Category 3", "Category 3 comment"))
-    
+
     #--------- datalist example
     datalist = create_datalist_example()
     def apply_test(data):
@@ -497,11 +545,11 @@ if __name__ == "__main__":
     print "result:", fedit(datalist, title="Example",
                            comment="This is just an <b>example</b>.",
                            apply=apply_test)
-    
+
     #--------- datagroup example
     datagroup = create_datagroup_example()
     print "result:", fedit(datagroup, "Global title")
-        
+
     #--------- datagroup inside a datagroup example
     datalist = create_datalist_example()
     datagroup = create_datagroup_example()
