@@ -95,7 +95,9 @@ class ContourLabeler:
             a format string for the label. Default is '%1.3f'
             Alternatively, this can be a dictionary matching contour
             levels with arbitrary strings to use for each contour level
-            (i.e., fmt[level]=string)
+            (i.e., fmt[level]=string), or it can be any callable, such
+            as a :class:`~matplotlib.ticker.Formatter` instance, that
+            returns a string when called with a numeric contour level.
 
           *manual*:
             if *True*, contour labels will be placed manually using
@@ -206,7 +208,7 @@ class ContourLabeler:
         else:
             self.labels(inline,inline_spacing)
 
-        # Hold on to some old attribute names.  These are depricated and will
+        # Hold on to some old attribute names.  These are deprecated and will
         # be removed in the near future (sometime after 2008-08-01), but keeping
         # for now for backwards compatibility
         self.cl = self.labelTexts
@@ -217,11 +219,11 @@ class ContourLabeler:
         return self.labelTextsList
 
 
-    def print_label(self, linecontour,labelwidth):
-        "if contours are too short, don't plot a label"
+    def print_label(self, linecontour, labelwidth):
+        "Return False if contours are too short for a label."
         lcsize = len(linecontour)
         if lcsize > 10 * labelwidth:
-            return 1
+            return True
 
         xmax = np.amax(linecontour[:,0])
         xmin = np.amin(linecontour[:,0])
@@ -230,30 +232,29 @@ class ContourLabeler:
 
         lw = labelwidth
         if (xmax - xmin) > 1.2* lw or (ymax - ymin) > 1.2 * lw:
-            return 1
+            return True
         else:
-            return 0
+            return False
 
-    def too_close(self, x,y, lw):
-        "if there's a label already nearby, find a better place"
-        if self.labelXYs != []:
-            dist = [np.sqrt((x-loc[0]) ** 2 + (y-loc[1]) ** 2)
-                    for loc in self.labelXYs]
-            for d in dist:
-                if d < 1.2*lw:
-                    return 1
-                else: return 0
-        else: return 0
+    def too_close(self, x, y, lw):
+        "Return True if a label is already near this location."
+        for loc in self.labelXYs:
+            d = np.sqrt((x-loc[0]) ** 2 + (y-loc[1]) ** 2)
+            if d < 1.2*lw:
+                return True
+        return False
 
     def get_label_coords(self, distances, XX, YY, ysize, lw):
-        """ labels are ploted at a location with the smallest
-        dispersion of the contour from a straight line
-        unless there's another label nearby, in which case
-        the second best place on the contour is picked up
-        if there's no good place a label isplotted at the
-        beginning of the contour
         """
+        Return x, y, and the index of a label location.
 
+        Labels are plotted at a location with the smallest
+        deviation of the contour from a straight line
+        unless there is another label nearby, in which case
+        the next best place on the contour is picked up.
+        If all such candidates are rejected, the beginning
+        of the contour is chosen.
+        """
         hysize = int(ysize/2)
         adist = np.argsort(distances)
 
@@ -261,15 +262,16 @@ class ContourLabeler:
             x, y = XX[ind][hysize], YY[ind][hysize]
             if self.too_close(x,y, lw):
                 continue
-            else:
-                return x,y, ind
+            return x,y, ind
 
         ind = adist[0]
         x, y = XX[ind][hysize], YY[ind][hysize]
         return x,y, ind
 
     def get_label_width(self, lev, fmt, fsize):
-        "get the width of the label in points"
+        """
+        Return the width of the label in points.
+        """
         if not cbook.is_string_like(lev):
             lev = self.get_text(lev, fmt)
 
@@ -284,7 +286,7 @@ class ContourLabeler:
             img, _ = self._mathtext_parser.parse(lev, dpi=72, prop=self.labelFontProps)
             lw = img.get_width() # at dpi=72, the units are PostScript points
         else:
-            lw = (len(lev)) * fsize
+            lw = (len(lev)) * fsize * 0.6 # width is much less than "font size"
 
         return lw
 
@@ -293,6 +295,8 @@ class ContourLabeler:
         This computes actual onscreen label width.
         This uses some black magic to determine onscreen extent of non-drawn
         label.  This magic may not be very robust.
+
+        This method is not being used, and may be modified or removed.
         """
         # Find middle of axes
         xx = np.mean( np.asarray(self.ax.axis()).reshape(2,2), axis=1 )
@@ -326,13 +330,15 @@ class ContourLabeler:
         else:
             if isinstance(fmt,dict):
                 return fmt[lev]
+            elif callable(fmt):
+                return fmt(lev)
             else:
                 return fmt%lev
 
     def locate_label(self, linecontour, labelwidth):
-        """find a good place to plot a label (relatively flat
-        part of the contour) and the angle of rotation for the
-        text object
+        """
+        Find a good place to plot a label (relatively flat
+        part of the contour).
         """
 
         nsize= len(linecontour)
@@ -466,10 +472,10 @@ class ContourLabeler:
 
             # The current implementation removes contours completely
             # covered by labels.  Uncomment line below to keep
-            # original contour if this is the preferred behavoir.
+            # original contour if this is the preferred behavior.
             #if not len(nlc): nlc = [ lc ]
 
-        return (rotation,nlc)
+        return rotation, nlc
 
     def _get_label_text(self,x,y,rotation):
         dx,dy = self.ax.transData.inverted().transform_point((x,y))
@@ -547,6 +553,7 @@ class ContourLabeler:
             con = self.collections[icon]
             trans = con.get_transform()
             lw = self.get_label_width(lev, self.labelFmt, fsize)
+            lw *= self.ax.figure.dpi/72.0  # scale to screen coordinates
             additions = []
             paths = con.get_paths()
             for segNum, linepath in enumerate(paths):
@@ -662,7 +669,14 @@ class ContourSet(cm.ScalarMappable, ContourLabeler):
         self.colors = kwargs.get('colors', None)
         norm = kwargs.get('norm', None)
         self.extend = kwargs.get('extend', 'neither')
-        self.antialiased = kwargs.get('antialiased', True)
+        self.antialiased = kwargs.get('antialiased', None)
+        if self.antialiased is None and self.filled:
+            self.antialiased = False # eliminate artifacts; we are not
+                                     # stroking the boundaries.
+            # The default for line contours will be taken from
+            # the LineCollection default, which uses the
+            # rcParams['lines.antialiased']
+
         self.nchunk = kwargs.get('nchunk', 0)
         self.locator = kwargs.get('locator', None)
         if (isinstance(norm, colors.LogNorm)
@@ -734,11 +748,15 @@ class ContourSet(cm.ScalarMappable, ContourLabeler):
             tlinewidths = self._process_linewidths()
             self.tlinewidths = tlinewidths
             tlinestyles = self._process_linestyles()
+            aa = self.antialiased
+            if aa is not None:
+                aa = (self.antialiased,)
             for level, width, lstyle, segs in \
                     zip(self.levels, tlinewidths, tlinestyles, self.allsegs):
                 # Default zorder taken from LineCollection
                 zorder = kwargs.get('zorder', 2)
                 col = collections.LineCollection(segs,
+                                     antialiaseds = aa,
                                      linewidths = width,
                                      linestyle = lstyle,
                                      alpha=self.alpha,
@@ -880,9 +898,9 @@ class ContourSet(cm.ScalarMappable, ContourLabeler):
                 except:
                     raise TypeError(
                         "Last %s arg must give levels; see help(%s)" % (fn,fn))
-            if self.filled and len(lev) < 2:
-                raise ValueError("Filled contours require at least 2 levels.")
             self.levels = lev
+        if self.filled and len(self.levels) < 2:
+            raise ValueError("Filled contours require at least 2 levels.")
 
     def _process_levels(self):
         self._levels = list(self.levels)
@@ -1281,10 +1299,9 @@ class QuadContourSet(ContourSet):
         Use keyword args to control colors, linewidth, origin, cmap ... see
         below for more details.
 
-        *X*, *Y*, and *Z* must be arrays with the same dimensions.
-
-        *Z* may be a masked array, but filled contouring may not
-        handle internal masked regions correctly.
+        *X* and *Y* must both be 2-D with the same shape as *Z*, or they
+        must both be 1-D such that ``len(X)`` is the number of columns in
+        *Z* and ``len(Y)`` is the number of rows in *Z*.
 
         ``C = contour(...)`` returns a
         :class:`~matplotlib.contour.QuadContourSet` object.
@@ -1358,6 +1375,10 @@ class QuadContourSet(ContourSet):
             Override axis units by specifying an instance of a
             :class:`matplotlib.units.ConversionInterface`.
 
+          *antialiased*: [ True | False ]
+            enable antialiasing, overriding the defaults.  For
+            filled contours, the default is True.  For line contours,
+            it is taken from rcParams['lines.antialiased'].
 
         contour-only keyword arguments:
 
@@ -1385,9 +1406,6 @@ class QuadContourSet(ContourSet):
 
         contourf-only keyword arguments:
 
-          *antialiased*: [ True | False ]
-            enable antialiasing
-
           *nchunk*: [ 0 | integer ]
             If 0, no subdivision of the domain. Specify a positive integer to
             divide the domain into subdomains of roughly *nchunk* by *nchunk*
