@@ -132,7 +132,7 @@ def parse_yahoo_historical(fh, adjusted=True, asobject=False):
     return d.view(np.recarray)  # Close enough to former Bunch return
 
 
-def fetch_historical_yahoo(ticker, date1, date2, cachename=None):
+def fetch_historical_yahoo(ticker, date1, date2, cachename=None,dividends=False):
     """
     Fetch historical data for ticker between date1 and date2.  date1 and
     date2 are date or datetime instances, or (year, month, day) sequences.
@@ -143,6 +143,9 @@ def fetch_historical_yahoo(ticker, date1, date2, cachename=None):
     cachename is the name of the local file cache.  If None, will
     default to the md5 hash or the url (which incorporates the ticker
     and date range)
+    
+    set dividends=True to return dividends instead of price data.  With
+    this option set, parse functions will not work
 
     a file handle is returned
     """
@@ -160,11 +163,17 @@ def fetch_historical_yahoo(ticker, date1, date2, cachename=None):
         d2 = (date2.month-1, date2.day, date2.year)
 
 
-    urlFmt = 'http://table.finance.yahoo.com/table.csv?a=%d&b=%d&c=%d&d=%d&e=%d&f=%d&s=%s&y=0&g=d&ignore=.csv'
+    if dividends:
+        g='v'
+        verbose.report('Retrieving dividends instead of prices')
+    else:
+        g='d'
+
+    urlFmt = 'http://table.finance.yahoo.com/table.csv?a=%d&b=%d&c=%d&d=%d&e=%d&f=%d&s=%s&y=0&g=%s&ignore=.csv'
 
 
     url =  urlFmt % (d1[0], d1[1], d1[2],
-                     d2[0], d2[1], d2[2], ticker)
+                     d2[0], d2[1], d2[2], ticker, g)
 
 
     if cachename is None:
