@@ -42,7 +42,7 @@ License   : matplotlib license (PSF compatible)
             see license/LICENSE_TTFQUERY.
 """
 
-import os, sys, glob, subprocess, warnings
+import os, sys, subprocess, warnings
 try:
     set
 except NameError:
@@ -52,6 +52,7 @@ from matplotlib import afm
 from matplotlib import ft2font
 from matplotlib import rcParams, get_configdir
 from matplotlib.cbook import is_string_like
+import matplotlib.cbook as cbook
 from matplotlib.fontconfig_pattern import \
     parse_fontconfig_pattern, generate_fontconfig_pattern
 
@@ -123,6 +124,7 @@ MSFontDirectories   = [
 X11FontDirectories  = [
     # an old standard installation point
     "/usr/X11R6/lib/X11/fonts/TTF/",
+    "/usr/X11/lib/X11/fonts",
     # here is the new standard location for fonts
     "/usr/share/fonts/",
     # documented as a good place to install new fonts
@@ -134,7 +136,10 @@ X11FontDirectories  = [
 OSXFontDirectories = [
     "/Library/Fonts/",
     "/Network/Library/Fonts/",
-    "/System/Library/Fonts/"
+    "/System/Library/Fonts/",
+    # fonts installed via MacPorts
+    "/opt/local/share/fonts"
+    ""
 ]
 
 if not USE_FONTCONFIG:
@@ -155,6 +160,15 @@ def get_fontext_synonyms(fontext):
             'otf': ('ttf', 'otf'),
             'afm': ('afm',)}[fontext]
 
+def list_fonts(directory, extensions):
+    """
+    Return a list of all fonts matching any of the extensions,
+    possibly upper-cased, found recursively under the directory.
+    """
+    pattern = ';'.join(['*.%s;*.%s' % (ext, ext.upper())
+                        for ext in extensions])
+    return cbook.listFiles(directory, pattern)
+
 def win32FontDirectory():
     """
     Return the user-specified font directory for Win32.  This is
@@ -204,10 +218,7 @@ def win32InstalledFonts(directory=None, fontext='ttf'):
             continue
 
         if not local:
-            files = []
-            for ext in fontext:
-                files.extend(glob.glob(os.path.join(directory, '*.'+ext)))
-            return files
+            return list_fonts(directory, fontext)
         try:
             for j in range(_winreg.QueryInfoKey(local)[1]):
                 try:
@@ -221,71 +232,31 @@ def win32InstalledFonts(directory=None, fontext='ttf'):
                     continue
                 except WindowsError:
                     continue
-
+                except MemoryError:
+                    continue
             return items.keys()
         finally:
             _winreg.CloseKey(local)
     return None
 
-def OSXFontDirectory():
-    """
-    Return the system font directories for OS X.  This is done by
-    starting at the list of hardcoded paths in
-    :attr:`OSXFontDirectories` and returning all nested directories
-    within them.
-    """
-    fontpaths = []
-    def add(arg,directory,files):
-        fontpaths.append(directory)
-
-    for fontdir in OSXFontDirectories:
-        try:
-            if os.path.isdir(fontdir):
-                os.path.walk(fontdir, add, None)
-        except (IOError, OSError, TypeError, ValueError):
-            pass
-    return fontpaths
-
-def OSXInstalledFonts(directory=None, fontext='ttf'):
+def OSXInstalledFonts(directories=None, fontext='ttf'):
     """
     Get list of font files on OS X - ignores font suffix by default.
     """
-    if directory is None:
-        directory = OSXFontDirectory()
+    if directories is None:
+        directories = OSXFontDirectories
 
     fontext = get_fontext_synonyms(fontext)
 
     files = []
-    for path in directory:
+    for path in directories:
         if fontext is None:
-            files.extend(glob.glob(os.path.join(path,'*')))
+            files.extend(cbook.listFiles(path, '*'))
         else:
-            for ext in fontext:
-                files.extend(glob.glob(os.path.join(path, '*.'+ext)))
-                files.extend(glob.glob(os.path.join(path, '*.'+ext.upper())))
+            files.extend(list_fonts(path, fontext))
     return files
 
 
-def x11FontDirectory():
-    """
-    Return the system font directories for X11.  This is done by
-    starting at the list of hardcoded paths in
-    :attr:`X11FontDirectories` and returning all nested directories
-    within them.
-    """
-    fontpaths = []
-    def add(arg,directory,files):
-        fontpaths.append(directory)
-
-    for fontdir in X11FontDirectories:
-        try:
-            if os.path.isdir(fontdir):
-                os.path.walk(fontdir, add, None)
-        except (IOError, OSError, TypeError, ValueError):
-            pass
-    return fontpaths
-
-
 def get_fontconfig_fonts(fontext='ttf'):
     """
     Grab a list of all the fonts that are being tracked by fontconfig
@@ -334,7 +305,7 @@ def findSystemFonts(fontpaths=None, fontext='ttf'):
                 if len(ext)>1 and ext[1:].lower() in fontexts:
                     fontfiles[f] = 1
         else:
-            fontpaths = x11FontDirectory()
+            fontpaths = X11FontDirectories
             # check for OS X & load its fonts if present
             if sys.platform == 'darwin':
                 for f in OSXInstalledFonts(fontext=fontext):
@@ -347,10 +318,7 @@ def findSystemFonts(fontpaths=None, fontext='ttf'):
         fontpaths = [fontpaths]
 
     for path in fontpaths:
-        files = []
-        for ext in fontexts:
-            files.extend(glob.glob(os.path.join(path, '*.'+ext)))
-            files.extend(glob.glob(os.path.join(path, '*.'+ext.upper())))
+        files = list_fonts(path, fontexts)
         for fname in files:
             fontfiles[os.path.abspath(fname)] = 1
 
@@ -717,8 +685,14 @@ class FontProperties(object):
         return parse_fontconfig_pattern(pattern)
 
     def __hash__(self):
-        l = [(k, getattr(self, "get" + k)()) for k in sorted(self.__dict__)]
-        return hash(repr(l))
+        l = (tuple(self.get_family()),
+             self.get_slant(),
+             self.get_variant(),
+             self.get_weight(),
+             self.get_stretch(),
+             self.get_size_in_points(),
+             self.get_file())
+        return hash(l)
 
     def __str__(self):
         return self.get_fontconfig_pattern()
@@ -1169,7 +1143,7 @@ class FontManager:
         return abs(sizeval1 - sizeval2) / 72.0
 
     def findfont(self, prop, fontext='ttf', directory=None,
-                 fallback_to_default=True):
+                 fallback_to_default=True, rebuild_if_missing=True):
         """
         Search the font list for the font that most closely matches
         the :class:`FontProperties` *prop*.
@@ -1257,6 +1231,16 @@ class FontManager:
                 (prop, best_font.name, best_font.fname, best_score))
             result = best_font.fname
 
+        if not os.path.isfile(result):
+            if rebuild_if_missing:
+                verbose.report(
+                    'findfont: Found a missing font file.  Rebuilding cache.')
+                _rebuild()
+                return fontManager.findfont(
+                    prop, fontext, directory, True, False)
+            else:
+                raise ValueError("No valid font could be found")
+
         if directory is None:
             font_cache[hash(prop)] = result
         return result
@@ -1280,6 +1264,16 @@ def is_opentype_cff_font(filename):
         return result
     return False
 
+fontManager = None
+
+_fmcache = os.path.join(get_configdir(), 'fontList.cache')
+
+def _rebuild():
+    global fontManager
+    fontManager = FontManager()
+    pickle_dump(fontManager, _fmcache)
+    verbose.report("generated new fontManager")
+
 # The experimental fontconfig-based backend.
 if USE_FONTCONFIG and sys.platform != 'win32':
     import re
@@ -1317,16 +1311,6 @@ if USE_FONTCONFIG and sys.platform != 'win32':
         return result
 
 else:
-    _fmcache = os.path.join(get_configdir(), 'fontList.cache')
-
-    fontManager = None
-
-    def _rebuild():
-        global fontManager
-        fontManager = FontManager()
-        pickle_dump(fontManager, _fmcache)
-        verbose.report("generated new fontManager")
-
     try:
         fontManager = pickle_load(_fmcache)
         if (not hasattr(fontManager, '_version') or
