@@ -1,24 +1,15 @@
 """
-Place a legend on the axes at location loc.  Labels are a
-sequence of strings and loc can be a string or an integer
-specifying the legend location
+The legend module defines the Legend class, which is responsible for
+drawing legends associated with axes and/or figures.
 
-The location codes are
-
-  'best'         : 0, (only implemented for axis legends)
-  'upper right'  : 1,
-  'upper left'   : 2,
-  'lower left'   : 3,
-  'lower right'  : 4,
-  'right'        : 5,
-  'center left'  : 6,
-  'center right' : 7,
-  'lower center' : 8,
-  'upper center' : 9,
-  'center'       : 10,
-
-Return value is a sequence of text, line instances that make
-up the legend
+The Legend class can be considered as a container of legend handles
+and legend texts. Creation of corresponding legend handles from the
+plot elements in the axes or figures (e.g., lines, patches, etc.) are
+specified by the handler map, which defines the mapping between the
+plot elements and the legend handlers to be used (the default legend
+handlers are defined in the :mod:`~matplotlib.legend_handler` module). Note
+that not all kinds of artist are supported by the legend yet (See
+:ref:`plotting-guide-legend` for more information).
 """
 from __future__ import division
 import warnings
@@ -32,15 +23,29 @@ from matplotlib.font_manager import FontProperties
 from matplotlib.lines import Line2D
 from matplotlib.patches import Patch, Rectangle, Shadow, FancyBboxPatch
 from matplotlib.collections import LineCollection, RegularPolyCollection, \
-     CircleCollection
+     CircleCollection, PathCollection
 from matplotlib.transforms import Bbox, BboxBase, TransformedBbox, BboxTransformTo, BboxTransformFrom
 
 from matplotlib.offsetbox import HPacker, VPacker, TextArea, DrawingArea, DraggableOffsetBox
 
+from matplotlib.container import ErrorbarContainer, BarContainer, StemContainer
+import legend_handler
+
 
 class DraggableLegend(DraggableOffsetBox):
-    def __init__(self, legend, use_blit=False):
+    def __init__(self, legend, use_blit=False, update="loc"):
+        """
+        update : If "loc", update *loc* parameter of
+                 legend upon finalizing. If "bbox", update
+                 *bbox_to_anchor* parameter.
+        """
         self.legend=legend
+
+        if update in ["loc", "bbox"]:
+            self._update = update
+        else:
+            raise ValueError("update parameter '%s' is not supported." % update)
+
         DraggableOffsetBox.__init__(self, legend, legend._legend_box,
                                     use_blit=use_blit)
 
@@ -50,11 +55,33 @@ class DraggableLegend(DraggableOffsetBox):
     def finalize_offset(self):
         loc_in_canvas = self.get_loc_in_canvas()
 
+        if self._update == "loc":
+            self._update_loc(loc_in_canvas)
+        elif self._update == "bbox":
+            self._update_bbox_to_anchor(loc_in_canvas)
+        else:
+            raise RuntimeError("update parameter '%s' is not supported." % self.update)
+
+    def _update_loc(self, loc_in_canvas):
         bbox = self.legend.get_bbox_to_anchor()
+
+        # if bbox has zero width or height, the transformation is
+        # ill-defined. Fall back to the defaul bbox_to_anchor.
+        if bbox.width ==0 or bbox.height ==0:
+            self.legend.set_bbox_to_anchor(None)
+            bbox = self.legend.get_bbox_to_anchor()
+
         _bbox_transform = BboxTransformFrom(bbox)
         self.legend._loc = tuple(_bbox_transform.transform_point(loc_in_canvas))
 
 
+    def _update_bbox_to_anchor(self, loc_in_canvas):
+
+        tr = self.legend.axes.transAxes
+        loc_in_bbox = tr.transform_point(loc_in_canvas)
+
+        self.legend.set_bbox_to_anchor(loc_in_bbox)
+
 
 class Legend(Artist):
     """
@@ -79,8 +106,6 @@ class Legend(Artist):
     loc can be a tuple of the noramilzed coordinate values with
     respect its parent.
 
-    Return value is a sequence of text, line instances that make
-    up the legend
     """
 
 
@@ -121,6 +146,7 @@ class Legend(Artist):
                  borderpad = None,     # the whitespace inside the legend border
                  labelspacing=None, #the vertical space between the legend entries
                  handlelength=None, # the length of the legend handles
+                 handleheight=None, # the height of the legend handles
                  handletextpad=None, # the pad between the legend handle and text
                  borderaxespad=None, # the pad between the axes and legend border
                  columnspacing=None, # spacing between columns
@@ -133,11 +159,12 @@ class Legend(Artist):
                  title = None, # set a title for the legend
                  bbox_to_anchor = None, # bbox that the legend will be anchored.
                  bbox_transform = None, # transform for the bbox
-                 frameon = True, # draw frame
+                 frameon = None, # draw frame
+                 handler_map = None,
                  ):
         """
         - *parent* : the artist that contains the legend
-        - *handles* : a list of artists (lines, patches) to add to the legend
+        - *handles* : a list of artists (lines, patches) to be added to the legend
         - *labels* : a list of strings to label the legend
 
         Optional keyword arguments:
@@ -151,13 +178,14 @@ class Legend(Artist):
         numpoints          the number of points in the legend for line
         scatterpoints      the number of points in the legend for scatter plot
         scatteryoffsets    a list of yoffsets for scatter symbols in legend
-        frameon            if True, draw a frame (default is True)
+        frameon            if True, draw a frame around the legend. If None, use rc
         fancybox           if True, draw a frame with a round fancybox.  If None, use rc
         shadow             if True, draw a shadow behind legend
         ncol               number of columns
         borderpad          the fractional whitespace inside the legend border
         labelspacing       the vertical space between the legend entries
         handlelength       the length of the legend handles
+        handleheight       the length of the legend handles
         handletextpad      the pad between the legend handle and text
         borderaxespad      the pad between the axes and legend border
         columnspacing      the spacing between columns
@@ -167,7 +195,7 @@ class Legend(Artist):
         ================   ==================================================================
 
 
-The pad and spacing parameters are measure in font-size units.  E.g.,
+The pad and spacing parameters are measured in font-size units.  E.g.,
 a fontsize of 10 points and a handlelength=5 implies a handlelength of
 50 points.  Values from rcParams will be used if None.
 
@@ -197,12 +225,15 @@ in the normalized axes coordinate.
         self._fontsize = self.prop.get_size_in_points()
 
         propnames=['numpoints', 'markerscale', 'shadow', "columnspacing",
-                   "scatterpoints"]
+                   "scatterpoints", "handleheight"]
 
         self.texts = []
         self.legendHandles = []
         self._legend_title_box = None
 
+
+        self._handler_map = handler_map
+
         localdict = locals()
 
         for name in propnames:
@@ -249,7 +280,7 @@ in the normalized axes coordinate.
         self._ncol = ncol
 
         if self.numpoints <= 0:
-            raise ValueError("numpoints must be >= 0; it was %d"% numpoints)
+            raise ValueError("numpoints must be > 0; it was %d"% numpoints)
 
         # introduce y-offset for handles of the scatter plot
         if scatteryoffsets is None:
@@ -327,6 +358,8 @@ in the normalized axes coordinate.
         self._set_artist_props(self.legendPatch)
 
         self._drawFrame = frameon
+        if frameon is None:
+            self._drawFrame = rcParams["legend.frameon"]
 
         # init with null renderer
         self._init_legend_box(handles, labels)
@@ -437,6 +470,90 @@ in the normalized axes coordinate.
             return renderer.points_to_pixels(self._fontsize)
 
 
+    # _default_handler_map defines the default mapping between plot
+    # elements and the legend handlers.
+
+    _default_handler_map = {
+        StemContainer:legend_handler.HandlerStem(),
+        ErrorbarContainer:legend_handler.HandlerErrorbar(),
+        Line2D:legend_handler.HandlerLine2D(),
+        Patch:legend_handler.HandlerPatch(),
+        LineCollection:legend_handler.HandlerLineCollection(),
+        RegularPolyCollection:legend_handler.HandlerRegularPolyCollection(),
+        CircleCollection:legend_handler.HandlerCircleCollection(),
+        BarContainer:legend_handler.HandlerPatch(update_func=legend_handler.update_from_first_child),
+        tuple:legend_handler.HandlerTuple(),
+        PathCollection:legend_handler.HandlerPathCollection()
+        }
+
+    # (get|set|update)_default_handler_maps are public interfaces to
+    # modify the defalut handler map.
+
+    @classmethod
+    def get_default_handler_map(cls):
+        """
+        A class method that returns the default handler map.
+        """
+        return cls._default_handler_map
+
+    @classmethod
+    def set_default_handler_map(cls, handler_map):
+        """
+        A class method to set the default handler map.
+        """
+        cls._default_handler_map = handler_map
+
+    @classmethod
+    def update_default_handler_map(cls, handler_map):
+        """
+        A class method to update the default handler map.
+        """
+        cls._default_handler_map.update(handler_map)
+
+    def get_legend_handler_map(self):
+        """
+        return the handler map.
+        """
+
+        default_handler_map = self.get_default_handler_map()
+
+        if self._handler_map:
+            hm = default_handler_map.copy()
+            hm.update(self._handler_map)
+            return hm
+        else:
+            return default_handler_map
+
+    @staticmethod
+    def get_legend_handler(legend_handler_map, orig_handle):
+        """
+        return a legend handler from *legend_handler_map* that
+        corresponds to *orig_handler*.
+
+        *legend_handler_map* should be a dictionary object (that is
+        returned by the get_legend_handler_map method).
+
+        It first checks if the *orig_handle* itself is a key in the
+        *legend_hanler_map* and return the associated value.
+        Otherwised, it checks for each of the classes in its
+        method-resolution-order. If no matching key is found, it
+        returns None.
+        """
+        legend_handler_keys = legend_handler_map.keys()
+        if orig_handle in legend_handler_keys:
+            handler = legend_handler_map[orig_handle]
+        else:
+
+            for handle_type in type(orig_handle).mro():
+                if handle_type in legend_handler_map:
+                    handler = legend_handler_map[handle_type]
+                    break
+            else:
+                handler = None
+
+        return handler
+
+
     def _init_legend_box(self, handles, labels):
         """
         Initiallize the legend_box. The legend_box is an instance of
@@ -470,9 +587,9 @@ in the normalized axes coordinate.
 
         # The approximate height and descent of text. These values are
         # only used for plotting the legend handle.
-        height = self._approx_text_height() * 0.7
-        descent = 0.
-
+        descent = 0.35*self._approx_text_height()*(self.handleheight - 0.7)
+        # 0.35 and 0.7 are just heuristic numbers. this may need to be improbed
+        height = self._approx_text_height() * self.handleheight - descent
         # each handle needs to be drawn inside a box of (x, y, w, h) =
         # (0, -descent, width, height).  And their corrdinates should
         # be given in the display coordinates.
@@ -483,154 +600,37 @@ in the normalized axes coordinate.
         # manually set their transform to the self.get_transform().
 
 
-        for handle, lab in zip(handles, labels):
-            if isinstance(handle, RegularPolyCollection) or \
-                   isinstance(handle, CircleCollection):
-                npoints = self.scatterpoints
-            else:
-                npoints = self.numpoints
-            if npoints > 1:
-                # we put some pad here to compensate the size of the
-                # marker
-                xdata = np.linspace(0.3*fontsize,
-                                    (self.handlelength-0.3)*fontsize,
-                                    npoints)
-                xdata_marker = xdata
-            elif npoints == 1:
-                xdata = np.linspace(0, self.handlelength*fontsize, 2)
-                xdata_marker = [0.5*self.handlelength*fontsize]
+        legend_handler_map = self.get_legend_handler_map()
 
-            if isinstance(handle, Line2D):
-                ydata = ((height-descent)/2.)*np.ones(xdata.shape, float)
-                legline = Line2D(xdata, ydata)
+        for orig_handle, lab in zip(handles, labels):
 
-                legline.update_from(handle)
-                self._set_artist_props(legline) # after update
-                legline.set_clip_box(None)
-                legline.set_clip_path(None)
-                legline.set_drawstyle('default')
-                legline.set_marker('None')
+            handler = self.get_legend_handler(legend_handler_map, orig_handle)
 
-                handle_list.append(legline)
-
-                legline_marker = Line2D(xdata_marker, ydata[:len(xdata_marker)])
-                legline_marker.update_from(handle)
-                self._set_artist_props(legline_marker)
-                legline_marker.set_clip_box(None)
-                legline_marker.set_clip_path(None)
-                legline_marker.set_linestyle('None')
-                if self.markerscale !=1:
-                    newsz = legline_marker.get_markersize()*self.markerscale
-                    legline_marker.set_markersize(newsz)
-                # we don't want to add this to the return list because
-                # the texts and handles are assumed to be in one-to-one
-                # correpondence.
-                legline._legmarker = legline_marker
-
-            elif isinstance(handle, Patch):
-                p = Rectangle(xy=(0., 0.),
-                              width = self.handlelength*fontsize,
-                              height=(height-descent),
-                              )
-                p.update_from(handle)
-                self._set_artist_props(p)
-                p.set_clip_box(None)
-                p.set_clip_path(None)
-                handle_list.append(p)
-            elif isinstance(handle, LineCollection):
-                ydata = ((height-descent)/2.)*np.ones(xdata.shape, float)
-                legline = Line2D(xdata, ydata)
-                self._set_artist_props(legline)
-                legline.set_clip_box(None)
-                legline.set_clip_path(None)
-                lw = handle.get_linewidth()[0]
-                dashes = handle.get_dashes()[0]
-                color = handle.get_colors()[0]
-                legline.set_color(color)
-                legline.set_linewidth(lw)
-                if dashes[0] is not None: # dashed line
-                    legline.set_dashes(dashes[1])
-                handle_list.append(legline)
-
-            elif isinstance(handle, RegularPolyCollection):
-
-                #ydata = self._scatteryoffsets
-                ydata = height*self._scatteryoffsets
-
-                size_max, size_min = max(handle.get_sizes())*self.markerscale**2,\
-                                     min(handle.get_sizes())*self.markerscale**2
-                if self.scatterpoints < 4:
-                    sizes = [.5*(size_max+size_min), size_max,
-                             size_min]
-                else:
-                    sizes = (size_max-size_min)*np.linspace(0,1,self.scatterpoints)+size_min
-
-                p = type(handle)(handle.get_numsides(),
-                                 rotation=handle.get_rotation(),
-                                 sizes=sizes,
-                                 offsets=zip(xdata_marker,ydata),
-                                 transOffset=self.get_transform(),
-                                 )
-
-                p.update_from(handle)
-                p.set_figure(self.figure)
-                p.set_clip_box(None)
-                p.set_clip_path(None)
-                handle_list.append(p)
-
-            elif isinstance(handle, CircleCollection):
-
-                ydata = height*self._scatteryoffsets
-
-                size_max, size_min = max(handle.get_sizes())*self.markerscale**2,\
-                                     min(handle.get_sizes())*self.markerscale**2
-                if self.scatterpoints < 4:
-                    sizes = [.5*(size_max+size_min), size_max,
-                             size_min]
-                else:
-                    sizes = (size_max-size_min)*np.linspace(0,1,self.scatterpoints)+size_min
-
-                p = type(handle)(sizes,
-                                 offsets=zip(xdata_marker,ydata),
-                                 transOffset=self.get_transform(),
-                                 )
-
-                p.update_from(handle)
-                p.set_figure(self.figure)
-                p.set_clip_box(None)
-                p.set_clip_path(None)
-                handle_list.append(p)
-            else:
-                handle_type = type(handle)
-                warnings.warn("Legend does not support %s\nUse proxy artist instead.\n\nhttp://matplotlib.sourceforge.net/users/legend_guide.html#using-proxy-artist\n" % (str(handle_type),))
+            if handler is None:
+                warnings.warn("Legend does not support %s\nUse proxy artist instead.\n\nhttp://matplotlib.sourceforge.net/users/legend_guide.html#using-proxy-artist\n" % (str(orig_handle),))
                 handle_list.append(None)
+                continue
+
+            textbox = TextArea(lab, textprops=label_prop,
+                               multilinebaseline=True, minimumdescent=True)
+            text_list.append(textbox._text)
+
+            labelboxes.append(textbox)
+
+            handlebox = DrawingArea(width=self.handlelength*fontsize,
+                                    height=height,
+                                    xdescent=0., ydescent=descent)
+
+            handle = handler(self, orig_handle, \
+                             #xdescent, ydescent, width, height,
+                             fontsize,
+                             handlebox)
+            handle_list.append(handle)
 
 
 
-            handle = handle_list[-1]
-            if handle is not None: # handle is None is the artist is not supproted
-                textbox = TextArea(lab, textprops=label_prop,
-                                   multilinebaseline=True, minimumdescent=True)
-                text_list.append(textbox._text)
 
-                labelboxes.append(textbox)
-
-                handlebox = DrawingArea(width=self.handlelength*fontsize,
-                                        height=height,
-                                        xdescent=0., ydescent=descent)
-
-                handlebox.add_artist(handle)
-
-                # special case for collection instances
-                if isinstance(handle, RegularPolyCollection) or \
-                       isinstance(handle, CircleCollection):
-                    handle._transOffset = handlebox.get_transform()
-                    handle.set_transform(None)
-
-
-                if hasattr(handle, "_legmarker"):
-                    handlebox.add_artist(handle._legmarker)
-                handleboxes.append(handlebox)
+            handleboxes.append(handlebox)
 
 
         if len(handleboxes) > 0:
@@ -780,9 +780,9 @@ in the normalized axes coordinate.
         'return Text instance for the legend title'
         return self._legend_title_box._text
 
-    def get_window_extent(self):
+    def get_window_extent(self, *args, **kwargs) :
         'return a extent of the the legend'
-        return self.legendPatch.get_window_extent()
+        return self.legendPatch.get_window_extent(*args, **kwargs)
 
 
     def get_frame_on(self):
@@ -925,7 +925,7 @@ in the normalized axes coordinate.
         return ox, oy
 
 
-    def draggable(self, state=None, use_blit=False):
+    def draggable(self, state=None, use_blit=False, update="loc"):
         """
         Set the draggable state -- if state is
 
@@ -938,6 +938,10 @@ in the normalized axes coordinate.
         If draggable is on, you can drag the legend on the canvas with
         the mouse.  The DraggableLegend helper instance is returned if
         draggable is on.
+
+        The update parameter control which parameter of the legend changes
+        when dragged. If update is "loc", the *loc* paramter of the legend
+        is changed. If "bbox", the *bbox_to_anchor* parameter is changed.
         """
         is_draggable = self._draggable is not None
 
@@ -947,7 +951,7 @@ in the normalized axes coordinate.
 
         if state:
             if self._draggable is None:
-                self._draggable = DraggableLegend(self, use_blit)
+                self._draggable = DraggableLegend(self, use_blit, update=update)
         else:
             if self._draggable is not None:
                 self._draggable.disconnect()
