@@ -14,7 +14,7 @@ is recommended that the namespaces be kept separate, e.g.::
 
 """
 
-import sys
+import sys, warnings
 
 import matplotlib
 from matplotlib import _pylab_helpers, interactive
@@ -92,7 +92,7 @@ _backend_selection()
 ## Global ##
 
 from matplotlib.backends import pylab_setup
-new_figure_manager, draw_if_interactive, show = pylab_setup()
+new_figure_manager, draw_if_interactive, _show = pylab_setup()
 
 @docstring.copy_dedent(Artist.findobj)
 def findobj(o=None, match=None):
@@ -113,16 +113,35 @@ def switch_backend(newbackend):
     Calling this command will close all open windows.
     """
     close('all')
-    global new_figure_manager, draw_if_interactive, show
+    global new_figure_manager, draw_if_interactive, _show
     matplotlib.use(newbackend, warn=False)
     reload(matplotlib.backends)
     from matplotlib.backends import pylab_setup
-    new_figure_manager, draw_if_interactive, show = pylab_setup()
+    new_figure_manager, draw_if_interactive, _show = pylab_setup()
+
+
+def show(*args, **kw):
+    """
+    When running in ipython with its pylab mode, display all
+    figures and return to the ipython prompt.
+
+    In non-interactive mode, display all figures and block until
+    the figures have been closed; in interactive mode it has no
+    effect unless figures were created prior to a change from
+    non-interactive to interactive mode (not recommended).  In
+    that case it displays the figures but does not block.
+
+    A single experimental keyword argument, *block*, may be
+    set to True or False to override the blocking behavior
+    described above.
+    """
+    global _show
+    _show(*args, **kw)
 
 
 def isinteractive():
     """
-    Return the interactive status
+    Return *True* if matplotlib is in interactive mode, *False* otherwise.
     """
     return matplotlib.is_interactive()
 
@@ -134,6 +153,39 @@ def ion():
     'Turn interactive mode on.'
     matplotlib.interactive(True)
 
+def pause(interval):
+    """
+    Pause for *interval* seconds.
+
+    If there is an active figure it will be updated and displayed,
+    and the gui event loop will run during the pause.
+
+    If there is no active figure, or if a non-interactive backend
+    is in use, this executes time.sleep(interval).
+
+    This can be used for crude animation. For more complex
+    animation, see :mod:`matplotlib.animation`.
+
+    This function is experimental; its behavior may be changed
+    or extended in a future release.
+
+    """
+    backend = rcParams['backend']
+    if backend in _interactive_bk:
+        figManager = _pylab_helpers.Gcf.get_active()
+        if figManager is not None:
+            canvas = figManager.canvas
+            canvas.draw()
+            show(block=False)
+            canvas.start_event_loop(interval)
+            return
+
+    # No on-screen figure is active, so sleep() is all we need.
+    import time
+    time.sleep(interval)
+
+
+
 @docstring.copy_dedent(matplotlib.rc)
 def rc(*args, **kwargs):
     matplotlib.rc(*args, **kwargs)
@@ -217,6 +269,14 @@ def figure(num=None, # autoincrement if None, else integer from 1-N
 
       figure(1)
 
+    The same applies if *num* is a string. In this case *num* will be used
+    as an explicit figure label::
+
+      figure("today")
+
+    and in windowed backends, the window title will be set to this figure
+    label.
+
     If you are creating many figures, make sure you explicitly call "close"
     on the figures you are not using, because this will enable pylab
     to properly clean up the memory.
@@ -247,16 +307,29 @@ def figure(num=None, # autoincrement if None, else integer from 1-N
     if facecolor is None : facecolor = rcParams['figure.facecolor']
     if edgecolor is None : edgecolor = rcParams['figure.edgecolor']
 
+    allnums = get_fignums()
+    figLabel = ''
     if num is None:
-        allnums = [f.num for f in _pylab_helpers.Gcf.get_all_fig_managers()]
         if allnums:
             num = max(allnums) + 1
         else:
             num = 1
+    elif is_string_like(num):
+        figLabel = num
+        allLabels = get_figlabels()
+        if figLabel not in allLabels:
+            if figLabel == 'all':
+                warnings.warn("close('all') closes all existing figures")
+            if len(allLabels):
+                num = max(allnums) + 1
+            else:
+                num = 1
+        else:
+            inum = allLabels.index(figLabel)
+            num = allnums[inum]
     else:
         num = int(num)  # crude validation of num argument
 
-
     figManager = _pylab_helpers.Gcf.get_fig_manager(num)
     if figManager is None:
         if get_backend().lower() == 'ps':  dpi = 72
@@ -269,6 +342,10 @@ def figure(num=None, # autoincrement if None, else integer from 1-N
                                              FigureClass=FigureClass,
                                              **kwargs)
 
+        if figLabel:
+            figManager.set_window_title(figLabel)
+            figManager.canvas.figure.set_label(figLabel)
+
         # make this figure current on button press event
         def make_active(event):
             _pylab_helpers.Gcf.set_active(figManager)
@@ -299,6 +376,12 @@ def get_fignums():
     fignums.sort()
     return fignums
 
+def get_figlabels():
+    "Return a list of existing figure labels."
+    figManagers = _pylab_helpers.Gcf.get_all_fig_managers()
+    figManagers.sort(key=lambda m: m.num)
+    return [m.canvas.figure.get_label() for m in figManagers]
+
 def get_current_fig_manager():
     figManager = _pylab_helpers.Gcf.get_active()
     if figManager is None:
@@ -320,9 +403,11 @@ def close(*args):
 
     ``close()`` by itself closes the current figure
 
+    ``close(h)`` where *h* is a :class:`Figure` instance, closes that figure
+
     ``close(num)`` closes figure number *num*
 
-    ``close(h)`` where *h* is a :class:`Figure` instance, closes that figure
+    ``close(name)`` where *name* is a string, closes figure with that label
 
     ``close('all')`` closes all the figure windows
     """
@@ -338,6 +423,11 @@ def close(*args):
             _pylab_helpers.Gcf.destroy_all()
         elif isinstance(arg, int):
             _pylab_helpers.Gcf.destroy(arg)
+        elif is_string_like(arg):
+            allLabels = get_figlabels()
+            if arg in allLabels:
+                num = get_fignums()[allLabels.index(arg)]
+                _pylab_helpers.Gcf.destroy(num)
         elif isinstance(arg, Figure):
             _pylab_helpers.Gcf.destroy_fig(arg)
         else:
@@ -354,7 +444,25 @@ def clf():
     draw_if_interactive()
 
 def draw():
-    'redraw the current figure'
+    """
+    Redraw the current figure.
+
+    This is used in interactive mode to update a figure that
+    has been altered using one or more plot object method calls;
+    it is not needed if figure modification is done entirely
+    with pyplot functions, if a sequence of modifications ends
+    with a pyplot function, or if matplotlib is in non-interactive
+    mode and the sequence of modifications ends with :func:`show` or
+    :func:`savefig`.
+
+    A more object-oriented alternative, given any
+    :class:`~matplotlib.figure.Figure` instance, :attr:`fig`, that
+    was created using a :mod:`~matplotlib.pyplot` function, is::
+
+        fig.canvas.draw()
+
+
+    """
     get_current_fig_manager().canvas.draw()
 
 @docstring.copy_dedent(Figure.savefig)
@@ -684,19 +792,27 @@ def subplots(nrows=1, ncols=1, sharex=False, sharey=False, squeeze=True,
       Number of columns of the subplot grid.  Defaults to 1.
 
     sharex : bool
-      If True, the X axis will be shared amongst all subplots.
+      If True, the X axis will be shared amongst all subplots.  If
+      True and you have multiple rows, the x tick labels on all but
+      the last row of plots will have visible set to False
 
-    sharex : bool
-      If True, the Y axis will be shared amongst all subplots.
+    sharey : bool
+      If True, the Y axis will be shared amongst all subplots. If
+      True and you have multiple columns, the y tick labels on all but
+      the first column of plots will have visible set to False
 
     squeeze : bool
-
       If True, extra dimensions are squeezed out from the returned axis object:
-        - if only one subplot is constructed (nrows=ncols=1), the resulting
-        single Axis object is returned as a scalar.
-        - for Nx1 or 1xN subplots, the returned object is a 1-d numpy object
-        array of Axis objects are returned as numpy 1-d arrays.
-        - for NxM subplots with N>1 and M>1 are returned as a 2d array.
+
+        - if only one subplot is constructed (nrows=ncols=1), the
+          resulting single Axis object is returned as a scalar.
+
+        - for Nx1 or 1xN subplots, the returned object is a 1-d numpy
+          object array of Axis objects are returned as numpy 1-d
+          arrays.
+
+        - for NxM subplots with N>1 and M>1 are returned as a 2d
+          array.
 
       If False, no squeezing at all is done: the returned axis object is always
       a 2-d array contaning Axis instances, even if it ends up being 1x1.
@@ -712,10 +828,13 @@ def subplots(nrows=1, ncols=1, sharex=False, sharey=False, squeeze=True,
     Returns:
 
     fig, ax : tuple
+
       - fig is the Matplotlib Figure object
-      - ax can be either a single axis object or an array of axis objects if
-      more than one supblot was created.  The dimensions of the resulting array
-      can be controlled with the squeeze keyword, see above.
+
+      - ax can be either a single axis object or an array of axis
+        objects if more than one supblot was created.  The dimensions
+        of the resulting array can be controlled with the squeeze
+        keyword, see above.
 
     **Examples:**
 
@@ -760,17 +879,39 @@ def subplots(nrows=1, ncols=1, sharex=False, sharey=False, squeeze=True,
     for i in range(1, nplots):
         axarr[i] = fig.add_subplot(nrows, ncols, i+1, **subplot_kw)
 
+
+
+    # returned axis array will be always 2-d, even if nrows=ncols=1
+    axarr = axarr.reshape(nrows, ncols)
+
+
+    # turn off redundant tick labeling
+    if sharex and nrows>1:
+        # turn off all but the bottom row
+        for ax in axarr[:-1,:].flat:
+            for label in ax.get_xticklabels():
+                label.set_visible(False)
+
+
+    if sharey and ncols>1:
+        # turn off all but the first column
+        for ax in axarr[:,1:].flat:
+            for label in ax.get_yticklabels():
+                label.set_visible(False)
+
     if squeeze:
         # Reshape the array to have the final desired dimension (nrow,ncol),
         # though discarding unneeded dimensions that equal 1.  If we only have
         # one subplot, just return it instead of a 1-element array.
         if nplots==1:
-            return fig, axarr[0]
+            ret = fig, axarr[0,0]
         else:
-            return fig, axarr.reshape(nrows, ncols).squeeze()
+            ret = fig, axarr.squeeze()
     else:
         # returned axis array will be always 2-d, even if nrows=ncols=1
-        return fig, axarr.reshape(nrows, ncols)
+        ret = fig, axarr.reshape(nrows, ncols)
+
+    return ret
 
 
 from gridspec import GridSpec
@@ -892,6 +1033,26 @@ def subplot_tool(targetfig=None):
     return ret
 
 
+
+def tight_layout(pad=1.2, h_pad=None, w_pad=None):
+    """
+    Adjust subplot parameters to give specified padding.
+
+    Parameters:
+
+    pad : float
+        padding between the figure edge and the edges of subplots, as a fraction of the font-size.
+    h_pad, w_pad : float
+        padding (height/width) between edges of adjacent subplots.
+        Defaults to `pad_inches`.
+    """
+
+    fig = gcf()
+    fig.tight_layout(pad=pad, h_pad=h_pad, w_pad=w_pad)
+    draw_if_interactive()
+
+
+
 def box(on=None):
     """
     Turn the axes box on or off according to *on*.
@@ -1054,10 +1215,14 @@ def xlim(*args, **kwargs):
       xlim(xmax=3) # adjust the max leaving min unchanged
       xlim(xmin=1) # adjust the min leaving max unchanged
 
+    Setting limits turns autoscaling off for the x-axis.
+
     The new axis limits are returned as a length 2 tuple.
 
     """
     ax = gca()
+    if not args and not kwargs:
+        return ax.get_xlim()
     ret = ax.set_xlim(*args, **kwargs)
     draw_if_interactive()
     return ret
@@ -1077,9 +1242,13 @@ def ylim(*args, **kwargs):
       ylim(ymax=3) # adjust the max leaving min unchanged
       ylim(ymin=1) # adjust the min leaving max unchanged
 
+    Setting limits turns autoscaling off for the y-axis.
+
     The new axis limits are returned as a length 2 tuple.
     """
     ax = gca()
+    if not args and not kwargs:
+        return ax.get_ylim()
     ret = ax.set_ylim(*args, **kwargs)
     draw_if_interactive()
     return ret
@@ -1099,9 +1268,8 @@ def xscale(*args, **kwargs):
     %(scale_docs)s
     """
     ax = gca()
-    ret = ax.set_xscale(*args, **kwargs)
+    ax.set_xscale(*args, **kwargs)
     draw_if_interactive()
-    return ret
 
 @docstring.dedent_interpd
 def yscale(*args, **kwargs):
@@ -1117,9 +1285,8 @@ def yscale(*args, **kwargs):
     %(scale_docs)s
     """
     ax = gca()
-    ret = ax.set_yscale(*args, **kwargs)
+    ax.set_yscale(*args, **kwargs)
     draw_if_interactive()
-    return ret
 
 def xticks(*args, **kwargs):
     """
@@ -1378,7 +1545,9 @@ def plotting():
     setp            set a graphics property
     semilogx        log x axis
     semilogy        log y axis
-    show            show the figures
+    show            in non-interactive mode, display all figures and block
+                    until they have been closed; in interactive mode,
+                    show generally has no effect.
     specgram        a spectrogram plot
     stem            make a stem plot
     subplot         make a subplot (numrows, numcols, axesnum)
@@ -1585,8 +1754,10 @@ def matshow(A, fignum=None, **kw):
 
     Tick labels for the xaxis are placed on top.
 
-    With the exception of fignum, keyword arguments are passed to
-    :func:`~matplotlib.pyplot.imshow`.
+    With the exception of *fignum*, keyword arguments are passed to
+    :func:`~matplotlib.pyplot.imshow`.  You may set the *origin*
+    kwarg to "lower" if you want the first row in the array to be
+    at the bottom instead of the top.
 
 
     *fignum*: [ None | integer | False ]
@@ -1599,6 +1770,7 @@ def matshow(A, fignum=None, **kw):
 
       If *fignum* is *False* or 0, a new figure window will **NOT** be created.
     """
+    A = np.asanyarray(A)
     if fignum is False or fignum is 0:
         ax = gca()
     else:
@@ -2607,8 +2779,8 @@ def cla():
 # This function was autogenerated by boilerplate.py.  Do not edit as
 # changes will be lost
 @docstring.copy_dedent(Axes.grid)
-def grid(b=None, which='major', **kwargs):
-    ret =  gca().grid(b, which, **kwargs)
+def grid(b=None, which='major', axis='both', **kwargs):
+    ret =  gca().grid(b, which, axis, **kwargs)
     draw_if_interactive()
     return ret
 
