@@ -83,6 +83,22 @@ def compare_float( expected, actual, relTol = None, absTol = None ):
 # convert files with that extension to png format.
 converter = { }
 
+def make_external_conversion_command(cmd):
+   def convert(*args):
+      cmdline = cmd(*args)
+      oldname, newname = args
+      pipe = subprocess.Popen(cmdline, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+      stdout, stderr = pipe.communicate()
+      errcode = pipe.wait()
+      if not os.path.exists(newname) or errcode:
+         msg = "Conversion command failed:\n%s\n" % ' '.join(cmdline)
+         if stdout:
+            msg += "Standard output:\n%s\n" % stdout
+         if stderr:
+            msg += "Standard error:\n%s\n" % stderr
+         raise IOError, msg
+   return convert
+
 if matplotlib.checkdep_ghostscript() is not None:
    # FIXME: make checkdep_ghostscript return the command
    if sys.platform == 'win32':
@@ -92,13 +108,13 @@ if matplotlib.checkdep_ghostscript() is not None:
    cmd = lambda old, new: \
        [gs, '-q', '-sDEVICE=png16m', '-dNOPAUSE', '-dBATCH',
         '-sOutputFile=' + new, old]
-   converter['pdf'] = cmd
-   converter['eps'] = cmd
+   converter['pdf'] = make_external_conversion_command(cmd)
+   converter['eps'] = make_external_conversion_command(cmd)
 
 if matplotlib.checkdep_inkscape() is not None:
    cmd = lambda old, new: \
-       ['inkscape', old, '--export-png=' + new]
-   converter['svg'] = cmd
+             ['inkscape', '-z', old, '--export-png', new]
+   converter['svg'] = make_external_conversion_command(cmd)
 
 def comparable_formats():
    '''Returns the list of file formats that compare_images can compare
@@ -116,17 +132,11 @@ def convert(filename):
    newname = base + '_' + extension + '.png'
    if not os.path.exists(filename):
       raise IOError, "'%s' does not exist" % filename
-   cmd = converter[extension](filename, newname)
-   pipe = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-   stdout, stderr = pipe.communicate()
-   errcode = pipe.wait()
-   if not os.path.exists(newname) or errcode:
-      msg = "Conversion command failed:\n%s\n" % ' '.join(cmd)
-      if stdout:
-         msg += "Standard output:\n%s\n" % stdout
-      if stderr:
-         msg += "Standard error:\n%s\n" % stderr
-      raise IOError, msg
+   # Only convert the file if the destination doesn't already exist or
+   # is out of date.
+   if (not os.path.exists(newname) or
+       os.stat(newname).st_mtime < os.stat(filename).st_mtime):
+      converter[extension](filename, newname)
    return newname
 
 verifiers = { }
@@ -157,6 +167,15 @@ if matplotlib.checkdep_xmllint() and False:
    verifiers['svg'] = lambda filename: [
       'xmllint', '--valid', '--nowarning', '--noout', filename]
 
+def crop_to_same(actual_path, actual_image, expected_path, expected_image):
+   # clip the images to the same size -- this is useful only when
+   # comparing eps to pdf
+   if actual_path[-7:-4] == 'eps' and expected_path[-7:-4] == 'pdf':
+      aw, ah = actual_image.size
+      ew, eh = expected_image.size
+      actual_image = actual_image.crop((aw/2-ew/2, ah/2-eh/2, aw/2+ew/2, ah/2+eh/2))
+   return actual_image, expected_image
+
 def compare_images( expected, actual, tol, in_decorator=False ):
    '''Compare two image files - not the greatest, but fast and good enough.
 
@@ -193,12 +212,15 @@ def compare_images( expected, actual, tol, in_decorator=False ):
    # Convert the image to png
    extension = expected.split('.')[-1]
    if extension != 'png':
-      actual, expected = convert(actual), convert(expected)
+      actual = convert(actual)
+      expected = convert(expected)
 
    # open the image files and remove the alpha channel (if it exists)
    expectedImage = Image.open( expected ).convert("RGB")
    actualImage = Image.open( actual ).convert("RGB")
 
+   actualImage, expectedImage = crop_to_same(actual, actualImage, expected, expectedImage)
+
    # normalize the images
    expectedImage = ImageOps.autocontrast( expectedImage, 2 )
    actualImage = ImageOps.autocontrast( actualImage, 2 )
@@ -245,10 +267,13 @@ def compare_images( expected, actual, tol, in_decorator=False ):
 
 def save_diff_image( expected, actual, output ):
    from PIL import Image
-   expectedImage = np.array(Image.open( expected ).convert("RGB")).astype(np.float)
-   actualImage = np.array(Image.open( actual ).convert("RGB")).astype(np.float)
-   assert expectedImage.ndim==expectedImage.ndim
-   assert expectedImage.shape==expectedImage.shape
+   expectedImage = Image.open( expected ).convert("RGB")
+   actualImage = Image.open( actual ).convert("RGB")
+   actualImage, expectedImage = crop_to_same(actual, actualImage, expected, expectedImage)
+   expectedImage = np.array(expectedImage).astype(np.float)
+   actualImage = np.array(actualImage).astype(np.float)
+   assert expectedImage.ndim==actualImage.ndim
+   assert expectedImage.shape==actualImage.shape
    absDiffImage = abs(expectedImage-actualImage)
    # expand differences in luminance domain
    absDiffImage *= 10
