@@ -24,23 +24,32 @@ def test_formatter_ticker():
     fig = plt.figure()
     ax = plt.subplot( 111 )
     ax.set_xlabel( "x-label 001" )
-    fig.savefig( 'formatter_ticker_001' )
 
+    fig = plt.figure()
+    ax = plt.subplot( 111 )
+    ax.set_xlabel( "x-label 001" )
     ax.plot( xdata, ydata1, color='blue', xunits="sec" )
-    fig.savefig( 'formatter_ticker_002' )
 
+    fig = plt.figure()
+    ax = plt.subplot( 111 )
+    ax.set_xlabel( "x-label 001" )
+    ax.plot( xdata, ydata1, color='blue', xunits="sec" )
     ax.set_xlabel( "x-label 003" )
-    fig.savefig( 'formatter_ticker_003' )
 
+    fig = plt.figure()
+    ax = plt.subplot( 111 )
+    ax.plot( xdata, ydata1, color='blue', xunits="sec" )
     ax.plot( xdata, ydata2, color='green', xunits="hour" )
     ax.set_xlabel( "x-label 004" )
-    fig.savefig( 'formatter_ticker_004' )
 
     # See SF bug 2846058
     # https://sourceforge.net/tracker/?func=detail&aid=2846058&group_id=80706&atid=560720
+    fig = plt.figure()
+    ax = plt.subplot( 111 )
+    ax.plot( xdata, ydata1, color='blue', xunits="sec" )
+    ax.plot( xdata, ydata2, color='green', xunits="hour" )
     ax.set_xlabel( "x-label 005" )
     ax.autoscale_view()
-    fig.savefig( 'formatter_ticker_005' )
 
 @image_comparison(baseline_images=['offset_points'])
 def test_basic_annotate():
@@ -57,8 +66,6 @@ def test_basic_annotate():
     ax.annotate( 'local max', xy=(3, 1), xycoords='data',
                  xytext=(3, 3), textcoords='offset points' )
 
-    fig.savefig( 'offset_points' )
-
 @image_comparison(baseline_images=['polar_axes'])
 def test_polar_annotations():
     # you can specify the xypoint and the xytext in different
@@ -91,8 +98,6 @@ def test_polar_annotations():
                 verticalalignment='baseline',
                 )
 
-    fig.savefig( 'polar_axes' )
-
    #--------------------------------------------------------------------
 @image_comparison(baseline_images=['polar_coords'])
 def test_polar_coord_annotations():
@@ -122,7 +127,6 @@ def test_polar_coord_annotations():
 
     ax.set_xlim( -20, 20 )
     ax.set_ylim( -20, 20 )
-    fig.savefig( 'polar_coords' )
 
 @image_comparison(baseline_images=['fill_units'])
 def test_fill_units():
@@ -163,7 +167,6 @@ def test_fill_units():
               facecolor="blue" )
 
     fig.autofmt_xdate()
-    fig.savefig( 'fill_units' )
 
 @image_comparison(baseline_images=['single_point'])
 def test_single_point():
@@ -174,8 +177,6 @@ def test_single_point():
     plt.subplot( 212 )
     plt.plot( [1], [1], 'o' )
 
-    fig.savefig( 'single_point' )
-
 @image_comparison(baseline_images=['single_date'])
 def test_single_date():
     time1=[ 721964.0 ]
@@ -188,8 +189,6 @@ def test_single_date():
     plt.subplot( 212 )
     plt.plot( time1, data1, 'o', color='r' )
 
-    fig.savefig( 'single_date' )
-
 @image_comparison(baseline_images=['shaped_data'])
 def test_shaped_data():
     xdata = np.array([[ 0.53295185,  0.23052951,  0.19057629,  0.66724975,  0.96577916,
@@ -232,8 +231,6 @@ def test_shaped_data():
     plt.subplot( 414 )
     plt.plot( xdata[:,1], xdata[1,:], 'o' )
 
-    fig.savefig( 'shaped_data' )
-
 @image_comparison(baseline_images=['const_xy'])
 def test_const_xy():
     fig = plt.figure()
@@ -247,8 +244,6 @@ def test_const_xy():
     plt.subplot( 313 )
     plt.plot( np.ones( (10,) ), np.ones( (10,) ), 'o' )
 
-    fig.savefig( 'const_xy' )
-
 @image_comparison(baseline_images=['polar_wrap_180',
                                    'polar_wrap_360',
                                    ])
@@ -263,8 +258,6 @@ def test_polar_wrap():
     plt.polar( [179*D2R,  181*D2R], [0.2, 0.1], "g.-" )
     plt.rgrids( [0.05, 0.1, 0.15, 0.2, 0.25, 0.3] )
 
-    fig.savefig( 'polar_wrap_180' )
-
     fig = plt.figure()
 
     #NOTE: resolution=1 really should be the default
@@ -274,15 +267,15 @@ def test_polar_wrap():
     plt.polar( [358*D2R,  2*D2R], [0.2, 0.1], "r.-" )
     plt.rgrids( [0.05, 0.1, 0.15, 0.2, 0.25, 0.3] )
 
-    fig.savefig( 'polar_wrap_360' )
-
-@image_comparison(baseline_images=['polar_units'])
+@image_comparison(baseline_images=['polar_units', 'polar_units_2'])
 def test_polar_units():
     import matplotlib.testing.jpl_units as units
+    from nose.tools import assert_true
     units.register()
 
     pi = np.pi
     deg = units.UnitDbl( 1.0, "deg" )
+    km = units.UnitDbl( 1.0, "km" )
 
     x1 = [ pi/6.0, pi/4.0, pi/3.0, pi/2.0 ]
     x2 = [ 30.0*deg, 45.0*deg, 60.0*deg, 90.0*deg ]
@@ -297,7 +290,13 @@ def test_polar_units():
     # polar( x2, y1, color = "red", xunits="rad" )
     # polar( x2, y2, color = "green" )
 
-    fig.savefig( 'polar_units' )
+    fig = plt.figure()
+
+    # make sure runits and theta units work
+    y1 = [ y*km for y in y1 ]
+    plt.polar( x2, y1, color = "blue", thetaunits="rad", runits="km" )
+    assert_true( isinstance(plt.gca().get_xaxis().get_major_formatter(), units.UnitDblFormatter) )
+
 
 @image_comparison(baseline_images=['polar_rmin'])
 def test_polar_rmin():
@@ -310,8 +309,17 @@ def test_polar_rmin():
     ax.set_rmax(2.0)
     ax.set_rmin(0.5)
 
-    fig.savefig('polar_rmin')
+@image_comparison(baseline_images=['polar_theta_position'])
+def test_polar_theta_position():
+    r = np.arange(0, 3.0, 0.01)
+    theta = 2*np.pi*r
 
+    fig = plt.figure()
+    ax = fig.add_axes([0.1, 0.1, 0.8, 0.8], polar=True)
+    ax.plot(theta, r)
+    ax.set_theta_zero_location("NW")
+    ax.set_theta_direction('clockwise')
+    
 @image_comparison(baseline_images=['axvspan_epoch'])
 def test_axvspan_epoch():
     from datetime import datetime
@@ -331,8 +339,6 @@ def test_axvspan_epoch():
     ax = plt.gca()
     ax.set_xlim( t0 - 5.0*dt, tf + 5.0*dt )
 
-    fig.savefig( 'axvspan_epoch' )
-
 @image_comparison(baseline_images=['axhspan_epoch'])
 def test_axhspan_epoch():
     from datetime import datetime
@@ -352,8 +358,6 @@ def test_axhspan_epoch():
     ax = plt.gca()
     ax.set_ylim( t0 - 5.0*dt, tf + 5.0*dt )
 
-    fig.savefig( 'axhspan_epoch' )
-
 
 @image_comparison(baseline_images=['hexbin_extent'])
 def test_hexbin_extent():
@@ -366,17 +370,19 @@ def test_hexbin_extent():
     x, y = data
 
     ax.hexbin(x, y, extent=[.1, .3, .6, .7])
-    fig.savefig('hexbin_extent')
 
 @image_comparison(baseline_images=['nonfinite_limits'])
 def test_nonfinite_limits():
     x = np.arange(0., np.e, 0.01)
-    y = np.log(x)
+    olderr = np.seterr(divide='ignore') #silence divide by zero warning from log(0)
+    try:
+        y = np.log(x)
+    finally:
+        np.seterr(**olderr)
     x[len(x)/2] = np.nan
     fig = plt.figure()
     ax = fig.add_subplot(111)
     ax.plot(x, y)
-    fig.savefig('nonfinite_limits')
 
 @image_comparison(baseline_images=['imshow'])
 def test_imshow():
@@ -392,7 +398,6 @@ def test_imshow():
     ax = fig.add_subplot(111)
 
     ax.imshow(r)
-    fig.savefig('imshow')
 
 @image_comparison(baseline_images=['imshow_clip'], tol=1e-2)
 def test_imshow_clip():
@@ -419,7 +424,6 @@ def test_imshow_clip():
 
     #Plot the image clipped by the contour
     ax.imshow(r, clip_path=clip_path)
-    fig.savefig('imshow_clip')
 
 @image_comparison(baseline_images=['polycollection_joinstyle'])
 def test_polycollection_joinstyle():
@@ -437,8 +441,6 @@ def test_polycollection_joinstyle():
     ax.set_xticks([])
     ax.set_yticks([])
 
-    fig.savefig('polycollection_joinstyle')
-
 @image_comparison(baseline_images=['fill_between_interpolate'], tol=1e-2)
 def test_fill_between_interpolate():
     x = np.arange(0.0, 2, 0.02)
@@ -458,8 +460,6 @@ def test_fill_between_interpolate():
     ax1.fill_between(x, y1, y2, where=y2>=y1, facecolor='green', interpolate=True)
     ax1.fill_between(x, y1, y2, where=y2<=y1, facecolor='red', interpolate=True)
 
-    fig.savefig('fill_between_interpolate')
-
 @image_comparison(baseline_images=['symlog'])
 def test_symlog():
     x = np.array([0,1,2,4,6,9,12,24])
@@ -472,9 +472,44 @@ def test_symlog():
     ax.set_xscale=('linear')
     ax.set_ylim(-1,10000000)
 
-    fig.savefig('symlog')
+@image_comparison(baseline_images=['symlog2'])
+def test_symlog2():
+    # Numbers from -50 to 50, with 0.1 as step
+    x = np.arange(-50,50, 0.001)
 
-@image_comparison(baseline_images=['pcolormesh'])
+    fig = plt.figure()
+    ax = fig.add_subplot(511)
+    # Plots a simple linear function 'f(x) = x'
+    ax.plot(x, x)
+    ax.set_xscale('symlog', linthreshx=20.0)
+    ax.grid(True)
+
+    ax = fig.add_subplot(512)
+    # Plots a simple linear function 'f(x) = x'
+    ax.plot(x, x)
+    ax.set_xscale('symlog', linthreshx=2.0)
+    ax.grid(True)
+
+    ax = fig.add_subplot(513)
+    # Plots a simple linear function 'f(x) = x'
+    ax.plot(x, x)
+    ax.set_xscale('symlog', linthreshx=1.0)
+    ax.grid(True)
+
+    ax = fig.add_subplot(514)
+    # Plots a simple linear function 'f(x) = x'
+    ax.plot(x, x)
+    ax.set_xscale('symlog', linthreshx=0.1)
+    ax.grid(True)
+
+    ax = fig.add_subplot(515)
+    # Plots a simple linear function 'f(x) = x'
+    ax.plot(x, x)
+    ax.set_xscale('symlog', linthreshx=0.01)
+    ax.grid(True)
+    ax.set_ylim(-0.1, 0.1)
+    
+@image_comparison(baseline_images=['pcolormesh'], tol=0.02)
 def test_pcolormesh():
     n = 12
     x = np.linspace(-1.5,1.5,n)
@@ -490,20 +525,107 @@ def test_pcolormesh():
     Zm = ma.masked_where(np.fabs(Qz) < 0.5*np.amax(Qz), Z)
 
     fig = plt.figure()
-    ax = fig.add_subplot(121)
-    ax.pcolormesh(Qx,Qz,Z,  lw=0.5, edgecolors='k')
+    ax = fig.add_subplot(131)
+    ax.pcolormesh(Qx,Qz,Z, lw=0.5, edgecolors='k')
     ax.set_title('lw=0.5')
     ax.set_xticks([])
     ax.set_yticks([])
 
-    ax = fig.add_subplot(122)
+    ax = fig.add_subplot(132)
     ax.pcolormesh(Qx,Qz,Z, lw=3, edgecolors='k')
     ax.set_title('lw=3')
     ax.set_xticks([])
     ax.set_yticks([])
 
-    fig.savefig('pcolormesh')
+    ax = fig.add_subplot(133)
+    ax.pcolormesh(Qx,Qz,Z, shading="gouraud")
+    ax.set_title('gouraud')
+    ax.set_xticks([])
+    ax.set_yticks([])
+    
 
+@image_comparison(baseline_images=['canonical'])
+def test_canonical():
+    fig, ax = plt.subplots()
+    ax.plot([1,2,3])
+
+
+@image_comparison(baseline_images=['arc_ellipse'])
+def test_arc_ellipse():
+    from matplotlib import patches
+    xcenter, ycenter = 0.38, 0.52
+    width, height = 1e-1, 3e-1
+    angle = -30
+
+    theta = np.arange(0.0, 360.0, 1.0)*np.pi/180.0
+    x = width/2. * np.cos(theta)
+    y = height/2. * np.sin(theta)
+
+    rtheta = angle*np.pi/180.
+    R = np.array([
+        [np.cos(rtheta),  -np.sin(rtheta)],
+        [np.sin(rtheta), np.cos(rtheta)],
+        ])
+
+    x, y = np.dot(R, np.array([x, y]))
+    x += xcenter
+    y += ycenter
+
+    fig = plt.figure()
+    ax = fig.add_subplot(211, aspect='auto')
+    ax.fill(x, y, alpha=0.2, facecolor='yellow', edgecolor='yellow', linewidth=1, zorder=1)
+
+    e1 = patches.Arc((xcenter, ycenter), width, height,
+                 angle=angle, linewidth=2, fill=False, zorder=2)
+
+    ax.add_patch(e1)
+
+    ax = fig.add_subplot(212, aspect='equal')
+    ax.fill(x, y, alpha=0.2, facecolor='green', edgecolor='green', zorder=1)
+    e2 = patches.Arc((xcenter, ycenter), width, height,
+                 angle=angle, linewidth=2, fill=False, zorder=2)
+
+    ax.add_patch(e2)
+
+@image_comparison(baseline_images=['units_strings'])
+def test_units_strings():
+    # Make sure passing in sequences of strings doesn't cause the unit
+    # conversion registry to recurse infinitely
+    Id = ['50', '100', '150', '200', '250']
+    pout = ['0', '7.4', '11.4', '14.2', '16.3']
+    fig = plt.figure()
+    ax = fig.add_subplot(111)
+    ax.plot(Id, pout)
+
+@image_comparison(baseline_images=['markevery'])
+def test_markevery():
+    x = np.linspace(0, 10, 100)
+    y = np.sin(x) * np.sqrt(x/10 + 0.5)
+
+    # check marker only plot
+    fig = plt.figure()
+    ax = fig.add_subplot(111)
+    ax.plot(x, y, 'o', label='default')
+    ax.plot(x, y, 'd', markevery=None, label='mark all')
+    ax.plot(x, y, 's', markevery=10, label='mark every 10')
+    ax.plot(x, y, '+', markevery=(5, 20), label='mark every 5 starting at 10')
+    ax.legend()
+
+@image_comparison(baseline_images=['markevery_line'])
+def test_markevery_line():
+    x = np.linspace(0, 10, 100)
+    y = np.sin(x) * np.sqrt(x/10 + 0.5)
+
+    # check line/marker combos
+    fig = plt.figure()
+    ax = fig.add_subplot(111)
+    ax.plot(x, y, '-o', label='default')
+    ax.plot(x, y, '-d', markevery=None, label='mark all')
+    ax.plot(x, y, '-s', markevery=10, label='mark every 10')
+    ax.plot(x, y, '-+', markevery=(5, 20), label='mark every 5 starting at 10')
+    ax.legend()
+
+    
 if __name__=='__main__':
     import nose
     nose.runmodule(argv=['-s','--with-doctest'], exit=False)
