@@ -1,8 +1,9 @@
 import datetime
 import numpy as np
-from matplotlib.testing.decorators import image_comparison, knownfailureif
+from matplotlib.testing.decorators import image_comparison, knownfailureif, cleanup
 import matplotlib.pyplot as plt
-from nose.tools import assert_raises
+from nose.tools import assert_raises, assert_equal
+import warnings
 
 @image_comparison(baseline_images=['date_empty'])
 def test_date_empty():
@@ -12,7 +13,6 @@ def test_date_empty():
     fig = plt.figure()
     ax = fig.add_subplot(1,1,1)
     ax.xaxis_date()
-    fig.savefig('date_empty')
 
 @image_comparison(baseline_images=['date_axhspan'])
 def test_date_axhspan():
@@ -25,7 +25,6 @@ def test_date_axhspan():
     ax.set_ylim(t0-datetime.timedelta(days=5),
                 tf+datetime.timedelta(days=5))
     fig.subplots_adjust(left=0.25)
-    fig.savefig('date_axhspan')
 
 @image_comparison(baseline_images=['date_axvspan'])
 def test_date_axvspan():
@@ -38,8 +37,6 @@ def test_date_axvspan():
     ax.set_xlim(t0-datetime.timedelta(days=720),
                 tf+datetime.timedelta(days=720))
     fig.autofmt_xdate()
-    fig.savefig('date_axvspan')
-
 
 @image_comparison(baseline_images=['date_axhline'])
 def test_date_axhline():
@@ -52,7 +49,6 @@ def test_date_axhline():
     ax.set_ylim(t0-datetime.timedelta(days=5),
                 tf+datetime.timedelta(days=5))
     fig.subplots_adjust(left=0.25)
-    fig.savefig('date_axhline')
 
 @image_comparison(baseline_images=['date_axvline'])
 def test_date_axvline():
@@ -65,14 +61,17 @@ def test_date_axvline():
     ax.set_xlim(t0-datetime.timedelta(days=5),
                 tf+datetime.timedelta(days=5))
     fig.autofmt_xdate()
-    fig.savefig('date_axvline')
 
+@cleanup
 def test_too_many_date_ticks():
     # Attempt to test SF 2715172, see
     # https://sourceforge.net/tracker/?func=detail&aid=2715172&group_id=80706&atid=560720
     # setting equal datetimes triggers and expander call in
     # transforms.nonsingular which results in too many ticks in the
     # DayLocator.  This should trigger a Locator.MAXTICKS RuntimeError
+    warnings.filterwarnings('ignore',
+        'Attempting to set identical left==right results\\nin singular transformations; automatically expanding.\\nleft=\d*\.\d*, right=\d*\.\d*',
+        UserWarning, module='matplotlib.axes')
     t0 = datetime.datetime(2000, 1, 20)
     tf = datetime.datetime(2000, 1, 20)
     fig = plt.figure()
@@ -111,8 +110,6 @@ def test_RRuleLocator():
     ax.autoscale_view()
     fig.autofmt_xdate()
 
-    fig.savefig( 'RRuleLocator_bounds' )
-
 @image_comparison(baseline_images=['DateFormatter_fractionalSeconds'])
 def test_DateFormatter():
     import pylab
@@ -139,9 +136,33 @@ def test_DateFormatter():
     ax.autoscale_view()
     fig.autofmt_xdate()
 
-    fig.savefig( 'DateFormatter_fractionalSeconds' )
+def test_drange():
+    '''This test should check if drange works as expected, and if all the rounding errors
+    are fixed'''
+    from matplotlib import dates
+    start = datetime.datetime(2011, 1,1, tzinfo=dates.UTC)
+    end = datetime.datetime(2011, 1, 2, tzinfo=dates.UTC)
+    delta = datetime.timedelta(hours=1)
+    #We expect 24 values in drange(start, end, delta), because drange returns dates from
+    #an half open interval [start, end)
+    assert_equal(24, len(dates.drange(start, end, delta)))
+
+    #if end is a little bit later, we expect the range to contain one element more
+    end = end +datetime.timedelta(microseconds=1)
+    assert_equal(25, len(dates.drange(start, end, delta)))
+
+    #reset end
+    end = datetime.datetime(2011, 1, 2, tzinfo=dates.UTC)
+
+    #and tst drange with "complicated" floats:
+    # 4 hours = 1/6 day, this is an "dangerous" float
+    delta = datetime.timedelta(hours=4)
+    daterange = dates.drange(start, end, delta)
+    assert_equal(6, len(daterange))
+    assert_equal(dates.num2date(daterange[-1]), end-delta)
 
 #@image_comparison(baseline_images=['empty_date_bug'])
+@cleanup
 @knownfailureif(True)
 def test_empty_date_with_year_formatter():
     # exposes sf bug 2861426: https://sourceforge.net/tracker/?func=detail&aid=2861426&group_id=80706&atid=560720
