@@ -1,6 +1,6 @@
 import numpy as np
 import matplotlib
-from matplotlib.testing.decorators import image_comparison, knownfailureif
+from matplotlib.testing.decorators import image_comparison, knownfailureif, cleanup
 import matplotlib.pyplot as plt
 
 from pylab import *
@@ -27,7 +27,6 @@ def test_clipping():
     ax.set_ylim((-0.20, -0.28))
     ax.set_xticks([])
     ax.set_yticks([])
-    fig.savefig('clipping')
 
 @image_comparison(baseline_images=['overflow'], tol=1e-2)
 def test_overflow():
@@ -41,8 +40,6 @@ def test_overflow():
     ax.set_xticks([])
     ax.set_yticks([])
 
-    fig.savefig('overflow')
-
 @image_comparison(baseline_images=['clipping_diamond'])
 def test_diamond():
     x = np.array([0.0, 1.0, 0.0, -1.0, 0.0])
@@ -56,8 +53,7 @@ def test_diamond():
     ax.set_xticks([])
     ax.set_yticks([])
 
-    fig.savefig('clipping_diamond')
-
+@cleanup
 def test_noise():
     np.random.seed(0)
     x = np.random.uniform(size=(5000,)) * 50
@@ -77,6 +73,7 @@ def test_noise():
 
     assert len(simplified) == 3884
 
+@cleanup
 def test_sine_plus_noise():
     np.random.seed(0)
     x = np.sin(np.linspace(0, np.pi * 2.0, 1000)) + np.random.uniform(size=(1000,)) * 0.01
@@ -111,8 +108,6 @@ def test_simplify_curve():
     ax.set_xlim((0, 2))
     ax.set_ylim((0, 2))
 
-    fig.savefig('simplify_curve')
-
 @image_comparison(baseline_images=['hatch_simplify'])
 def test_hatch():
     fig = plt.figure()
@@ -121,8 +116,6 @@ def test_hatch():
     ax.set_xlim((0.45, 0.55))
     ax.set_ylim((0.45, 0.55))
 
-    fig.savefig('hatch_simplify')
-
 @image_comparison(baseline_images=['fft_peaks'])
 def test_fft_peaks():
     fig = plt.figure()
@@ -132,8 +125,6 @@ def test_fft_peaks():
     ax.set_xticks([])
     ax.set_yticks([])
 
-    fig.savefig('fft_peaks')
-
     path = p1[0].get_path()
     transform = p1[0].get_transform()
     path = transform.transform_path(path)
@@ -143,6 +134,7 @@ def test_fft_peaks():
 
     assert len(simplified) == 20
 
+@cleanup
 def test_start_with_moveto():
     # Should be entirely clipped away to a single MOVETO
     data = """
@@ -175,6 +167,7 @@ AAj1//+nPwAA/////w=="""
     assert len(segs) == 1
     assert segs[0][1] == Path.MOVETO
 
+@cleanup
 @raises(OverflowError)
 def test_throw_rendering_complexity_exceeded():
     rcParams['path.simplify'] = False
@@ -208,7 +201,6 @@ def test_clipper():
     ax.yaxis.set_ticks_position('left')
 
     ax.set_xlim(5, 9)
-    fig.savefig('clipper_edge')
 
 @image_comparison(baseline_images=['para_equal_perp'])
 def test_para_equal_perp():
@@ -219,7 +211,6 @@ def test_para_equal_perp():
     ax = fig.add_subplot(111)
     ax.plot(x + 1, y + 1)
     ax.plot(x + 1, y + 1, 'ro')
-    fig.savefig('para_equal_perp')
 
 if __name__=='__main__':
     import nose
