@@ -65,8 +65,8 @@ def dvipng_hack_alpha():
                 'helpful')
             version = distutils.version.LooseVersion(version)
             return version < distutils.version.LooseVersion('1.6')
-    raise RuntimeError('Could not obtain dvipng version')
-
+    mpl.verbose.report('No dvipng was found', 'helpful')
+    return False
 
 
 class TexManager:
@@ -91,8 +91,8 @@ WARNING: found a TeX cache dir in the deprecated location "%s".
     if not os.path.exists(texcache):
         os.mkdir(texcache)
 
-    _dvipng_hack_alpha = dvipng_hack_alpha()
-
+    _dvipng_hack_alpha = None
+    #_dvipng_hack_alpha = dvipng_hack_alpha()
     # mappable cache of
     rgba_arrayd = {}
     grey_arrayd = {}
@@ -304,7 +304,7 @@ WARNING: found a TeX cache dir in the deprecated location "%s".
 %s
 %s
 \usepackage[active,showbox,tightpage]{preview}
-%%\usepackage[papersize={72in,72in}, body={70in,70in}, margin={1in,1in}]{geometry}
+\usepackage[papersize={72in,72in}, body={70in,70in}, margin={1in,1in}]{geometry}
 
 %% we override the default showbox as it is treated as an error and makes
 %% the exit status not zero
@@ -455,7 +455,7 @@ string:\n%s\nHere is the full report generated by LaTeX: \n\n'% repr(tex)) + rep
                 report = 'No dvipng error report available.'
             if exit_status:
                 raise RuntimeError('dvipng was not able to \
-process the flowing file:\n%s\nHere is the full report generated by dvipng: \
+process the following file:\n%s\nHere is the full report generated by dvipng: \
 \n\n'% dvifile + report)
             else: mpl.verbose.report(report, 'debug')
             try: os.remove(outfile)
@@ -516,7 +516,10 @@ process the flowing file:\n%s\nHere is the full report generated by dvipng: \
             if rcParams['text.dvipnghack'] is not None:
                 hack = rcParams['text.dvipnghack']
             else:
-                hack = self._dvipng_hack_alpha
+                if TexManager._dvipng_hack_alpha is None:
+                    TexManager._dvipng_hack_alpha = dvipng_hack_alpha()
+                hack = TexManager._dvipng_hack_alpha
+
 
             if hack:
                 # hack the alpha channel
@@ -577,6 +580,8 @@ process the flowing file:\n%s\nHere is the full report generated by dvipng: \
         """
         return width, heigth and descent of the text.
         """
+        if tex.strip() == '':
+            return 0, 0, 0
 
         if renderer:
             dpi_fraction = renderer.points_to_pixels(1.)
