@@ -1,11 +1,14 @@
 #!/usr/bin/env python
 from pylab import *
 try:
-    import Image
+    from PIL import Image
 except ImportError, exc:
     raise SystemExit("PIL must be installed to run this example")
 
-lena = Image.open('../data/lena.jpg')
+import matplotlib.cbook as cbook
+
+datafile = cbook.get_sample_data('lena.jpg')
+lena = Image.open(datafile)
 dpi = rcParams['figure.dpi']
 figsize = lena.size[0]/dpi, lena.size[1]/dpi
 
@@ -14,6 +17,5 @@ ax = axes([0,0,1,1], frameon=False)
 ax.set_axis_off()
 im = imshow(lena, origin='lower')
 
-#savefig('image_demo3')
 show()
 
