@@ -1,11 +1,13 @@
 #!/usr/bin/env python
 # This file generates the matplotlib web page logo
 from pylab import *
-
+import matplotlib.cbook as cbook
 
 # convert data to mV
-x = 1000*0.1*fromstring(
-    file('../data/membrane.dat', 'rb').read(), float32)
+datafile = cbook.get_sample_data('membrane.dat', asfileobj=False)
+print 'loading', datafile
+
+x = 1000*0.1*fromstring(file(datafile, 'rb').read(), float32)
 # 0.0005 is the sample interval
 t = 0.0005*arange(len(x))
 figure(1, figsize=(7,1), dpi=100)
