@@ -42,7 +42,7 @@ def get_dir_vector(zdir):
         return np.array((0, 1, 0))
     elif zdir == 'z':
         return np.array((0, 0, 1))
-    elif zdir == None:
+    elif zdir is None:
         return np.array((0, 0, 0))
     elif iterable(zdir) and len(zdir) == 3:
         return zdir
@@ -162,6 +162,10 @@ class Line3DCollection(LineCollection):
         '''
         LineCollection.__init__(self, segments, *args, **kwargs)
 
+    def set_sort_zpos(self,val):
+        '''Set the position to use for z-sorting.'''
+        self._sort_zpos = val
+
     def set_segments(self, segments):
         '''
         Set 3D segments
@@ -291,8 +295,17 @@ class Patch3DCollection(PatchCollection):
         PatchCollection.__init__(self, *args, **kwargs)
         self._old_draw = lambda x: PatchCollection.draw(self, x)
 
+    def set_sort_zpos(self,val):
+        '''Set the position to use for z-sorting.'''
+        self._sort_zpos = val
+
     def set_3d_properties(self, zs, zdir):
-        xs, ys = zip(*self.get_offsets())
+        offsets = self.get_offsets()
+        if len(offsets) > 0:
+            xs, ys = zip(*self.get_offsets())
+        else:
+            xs = [0] * len(zs)
+            ys = [0] * len(zs)
         self._offsets3d = juggle_axes(xs, ys, zs, zdir)
         self._facecolor3d = self.get_facecolor()
         self._edgecolor3d = self.get_edgecolor()
@@ -306,7 +319,10 @@ class Patch3DCollection(PatchCollection):
         self.set_edgecolors(zalpha(self._edgecolor3d, vzs))
         PatchCollection.set_offsets(self, zip(vxs, vys))
 
-        return min(vzs)
+        if vzs.size > 0 :
+            return min(vzs)
+        else :
+            return np.nan
 
     def draw(self, renderer):
         self._old_draw(renderer)
@@ -382,7 +398,13 @@ class Poly3DCollection(PolyCollection):
             ei = si+len(p)
             segis.append((si, ei))
             si = ei
-        xs, ys, zs = zip(*points)
+
+        if len(segments3d) > 0 :
+            xs, ys, zs = zip(*points)
+        else :
+            # We need this so that we can skip the bad unpacking from zip()
+            xs, ys, zs = [], [], []
+
         ones = np.ones(len(xs))
         self._vec = np.array([xs, ys, zs, ones])
         self._segis = segis
@@ -445,11 +467,16 @@ class Poly3DCollection(PolyCollection):
 
         # Return zorder value
         if self._sort_zpos is not None:
-           zvec = np.array([[0], [0], [self._sort_zpos], [1]])
-           ztrans = proj3d.proj_transform_vec(zvec, renderer.M)
-           return ztrans[2][0]
-        else:
+            zvec = np.array([[0], [0], [self._sort_zpos], [1]])
+            ztrans = proj3d.proj_transform_vec(zvec, renderer.M)
+            return ztrans[2][0]
+        elif tzs.size > 0 :
+            # FIXME: Some results still don't look quite right.
+            #        In particular, examine contourf3d_demo2.py
+            #        with az = -54 and elev = -45.
             return np.min(tzs)
+        else :
+            return np.nan
 
     def set_facecolor(self, colors):
         PolyCollection.set_facecolor(self, colors)
@@ -546,8 +573,9 @@ def get_colors(c, num):
 def zalpha(colors, zs):
     """Modify the alphas of the color list according to depth"""
     colors = get_colors(colors, len(zs))
-    norm = Normalize(min(zs), max(zs))
-    sats = 1 - norm(zs) * 0.7
-    colors = [(c[0], c[1], c[2], c[3] * s) for c, s in zip(colors, sats)]
+    if zs.size > 0 :
+        norm = Normalize(min(zs), max(zs))
+        sats = 1 - norm(zs) * 0.7
+        colors = [(c[0], c[1], c[2], c[3] * s) for c, s in zip(colors, sats)]
     return colors
 
