@@ -1,3 +1,5 @@
+/* -*- mode: c++; c-basic-offset: 4 -*- */
+
 /* Python API mandates Python.h is included *first* */
 #include "Python.h"
 #include <string>
@@ -668,7 +670,7 @@ Image::set_interpolation(const Py::Tuple& args)
 
     args.verify_length(1);
 
-    size_t method = Py::Int(args[0]);
+    size_t method = (long)Py::Int(args[0]);
     interpolation = (unsigned)method;
     return Py::Object();
 }
@@ -702,7 +704,7 @@ Image::set_aspect(const Py::Tuple& args)
     _VERBOSE("Image::set_aspect");
 
     args.verify_length(1);
-    size_t method = Py::Int(args[0]);
+    size_t method = (long)Py::Int(args[0]);
     aspect = (unsigned)method;
     return Py::Object();
 
@@ -756,8 +758,8 @@ _image_module::from_images(const Py::Tuple& args)
 
     args.verify_length(3);
 
-    size_t numrows = (size_t)Py::Int(args[0]);
-    size_t numcols = (size_t)Py::Int(args[1]);
+    size_t numrows = (long)Py::Int(args[0]);
+    size_t numcols = (long)Py::Int(args[1]);
 
     if (numrows >= 32768 || numcols >= 32768)
     {
@@ -800,8 +802,8 @@ _image_module::from_images(const Py::Tuple& args)
     {
         tup = Py::Tuple(tups[imnum]);
         Image* thisim = static_cast<Image*>(tup[0].ptr());
-        ox = Py::Int(tup[1]);
-        oy = Py::Int(tup[2]);
+        ox = (long)Py::Int(tup[1]);
+        oy = (long)Py::Int(tup[2]);
         bool isflip = (thisim->rbufOut->stride()) < 0;
         //std::cout << "from images " << isflip << "; stride=" << thisim->rbufOut->stride() << std::endl;
         size_t ind = 0;
@@ -1083,7 +1085,7 @@ _image_module::frombyte(const Py::Tuple& args)
     Py::Object x = args[0];
     int isoutput = Py::Int(args[1]);
 
-    PyArrayObject *A = (PyArrayObject *) PyArray_ContiguousFromObject(x.ptr(), PyArray_UBYTE, 3, 3);
+    PyArrayObject *A = (PyArrayObject *) PyArray_FromObject(x.ptr(), PyArray_UBYTE, 3, 3);
     if (A == NULL)
     {
         throw Py::ValueError("Array must have 3 dimensions");
@@ -1102,35 +1104,86 @@ _image_module::frombyte(const Py::Tuple& args)
 
     agg::int8u *arrbuf;
     agg::int8u *buffer;
+    agg::int8u *dstbuf;
 
     arrbuf = reinterpret_cast<agg::int8u *>(A->data);
 
     size_t NUMBYTES(imo->colsIn * imo->rowsIn * imo->BPP);
-    buffer = new agg::int8u[NUMBYTES];
+    buffer = dstbuf = new agg::int8u[NUMBYTES];
 
     if (buffer == NULL) //todo: also handle allocation throw
     {
         throw Py::MemoryError("_image_module::frombyte could not allocate memory");
     }
 
-    const size_t N = imo->rowsIn * imo->colsIn * imo->BPP;
-    size_t i = 0;
-    if (A->dimensions[2] == 4)
+    if PyArray_ISCONTIGUOUS(A)
     {
-        memmove(buffer, arrbuf, N);
+        if (A->dimensions[2] == 4)
+        {
+            memmove(dstbuf, arrbuf, imo->rowsIn * imo->colsIn * 4);
+        }
+        else
+        {
+            size_t i = imo->rowsIn * imo->colsIn;
+            while (i--)
+            {
+                *dstbuf++ = *arrbuf++;
+                *dstbuf++ = *arrbuf++;
+                *dstbuf++ = *arrbuf++;
+                *dstbuf++ = 255;
+            }
+        }
+    }
+    else if ((A->strides[1] == 4) && (A->strides[2] == 1))
+    {
+        const size_t N = imo->colsIn * 4;
+        const size_t stride = A->strides[0];
+        for (size_t rownum = 0; rownum < imo->rowsIn; rownum++)
+        {
+            memmove(dstbuf, arrbuf, N);
+            arrbuf += stride;
+            dstbuf += N;
+        }
+    }
+    else if ((A->strides[1] == 3) && (A->strides[2] == 1))
+    {
+        const size_t stride = A->strides[0] - imo->colsIn * 3;
+        for (size_t rownum = 0; rownum < imo->rowsIn; rownum++)
+        {
+            for (size_t colnum = 0; colnum < imo->colsIn; colnum++)
+            {
+                *dstbuf++ = *arrbuf++;
+                *dstbuf++ = *arrbuf++;
+                *dstbuf++ = *arrbuf++;
+                *dstbuf++ = 255;
+            }
+            arrbuf += stride;
+        }
     }
     else
     {
-        while (i < N)
+        PyArrayIterObject *iter;
+        iter = (PyArrayIterObject *)PyArray_IterNew((PyObject *)A);
+        if (A->dimensions[2] == 4)
         {
-            memmove(buffer, arrbuf, 3);
-            buffer += 3;
-            arrbuf += 3;
-            *buffer++ = 255;
-            i += 4;
+            while (iter->index < iter->size) {
+                *dstbuf++ = *((unsigned char *)iter->dataptr);
+                PyArray_ITER_NEXT(iter);
+            }
         }
-        buffer -= N;
-        arrbuf -= imo->rowsIn * imo->colsIn;
+        else
+        {
+            while (iter->index < iter->size) {
+                *dstbuf++ = *((unsigned char *)iter->dataptr);
+                PyArray_ITER_NEXT(iter);
+                *dstbuf++ = *((unsigned char *)iter->dataptr);
+                PyArray_ITER_NEXT(iter);
+                *dstbuf++ = *((unsigned char *)iter->dataptr);
+                PyArray_ITER_NEXT(iter);
+                *dstbuf++ = 255;
+            }
+        }
+        Py_DECREF(iter);
     }
 
     if (isoutput)
@@ -1171,8 +1224,8 @@ _image_module::frombuffer(const Py::Tuple& args)
     args.verify_length(4);
 
     PyObject *bufin = new_reference_to(args[0]);
-    size_t x = Py::Int(args[1]);
-    size_t y = Py::Int(args[2]);
+    size_t x = (long)Py::Int(args[1]);
+    size_t y = (long)Py::Int(args[2]);
 
     if (x >= 32768 || y >= 32768)
     {
